@@ -2822,12 +2822,12 @@ edv_archiver_struct *EDVArchiverNew(edv_core_struct *core)
 	GtkCombo *combo;
 	GtkCList *clist;
 	const GtkTargetEntry dnd_tar_types[] = {
-{"text/plain",				0,	EDV_DND_TYPE_INFO_TEXT_PLAIN},
-{"text/uri-list",			0,	EDV_DND_TYPE_INFO_TEXT_URI_LIST},
-{"STRING",				0,	EDV_DND_TYPE_INFO_STRING}
+{"text/plain",				0,	EDV_DND_INFO_TEXT_PLAIN},
+{"text/uri-list",			0,	EDV_DND_INFO_TEXT_URI_LIST},
+{"STRING",				0,	EDV_DND_INFO_STRING}
 	};
 	const GtkTargetEntry dnd_src_types[] = {
-{EDV_DND_TYPE_STRING_ARCHIVE_OBJECT,	0,	EDV_DND_TYPE_INFO_ARCHIVE_OBJECT}
+{EDV_DND_TARGET_ARCHIVE_OBJECT,		0,	EDV_DND_INFO_ARCHIVE_OBJECT}
 	};
 	const cfg_item_struct *cfg_list;
 	edv_status_bar_struct *status_bar;
@@ -3139,9 +3139,9 @@ edv_archiver_struct *EDVArchiverNew(edv_core_struct *core)
 	{
 	    /* Need to set different dnd_src_types for the drag source */
 	    const GtkTargetEntry dnd_src_types[] = {
-{"text/plain",				0,	EDV_DND_TYPE_INFO_TEXT_PLAIN},
-{"text/uri-list",			0,	EDV_DND_TYPE_INFO_TEXT_URI_LIST},
-{"STRING",				0,	EDV_DND_TYPE_INFO_STRING}
+{"text/plain",				0,	EDV_DND_INFO_TEXT_PLAIN},
+{"text/uri-list",			0,	EDV_DND_INFO_TEXT_URI_LIST},
+{"STRING",				0,	EDV_DND_INFO_STRING}
 	    };
 	    GUIDNDSetSrc(
 		archiver->location_icon_fixed,
