@@ -122,9 +122,9 @@ static gint EDVArchiverDNDConfirm(
 	}
 
 	/* Do confirmation, handle by dnd target type */
-	if((info == EDV_DND_TYPE_INFO_TEXT_PLAIN) ||
-	   (info == EDV_DND_TYPE_INFO_TEXT_URI_LIST) ||
-	   (info == EDV_DND_TYPE_INFO_STRING)
+	if((info == EDV_DND_INFO_TEXT_PLAIN) ||
+	   (info == EDV_DND_INFO_TEXT_URI_LIST) ||
+	   (info == EDV_DND_INFO_STRING)
 	)
 	{
 	    switch(gdk_action)
@@ -140,11 +140,11 @@ static gint EDVArchiverDNDConfirm(
 		break;
 	    }
 	}
-	else if(info == EDV_DND_TYPE_INFO_RECYCLED_OBJECT)
+	else if(info == EDV_DND_INFO_RECYCLED_OBJECT)
 	{
 	    /* Recycled objects may not be put to an archive */
 	}
-	else if(info == EDV_DND_TYPE_INFO_ARCHIVE_OBJECT)
+	else if(info == EDV_DND_INFO_ARCHIVE_OBJECT)
 	{
 	    /* Objects in archives may not be put to an archive */
 	}
@@ -174,9 +174,9 @@ static void EDVArchiverDNDUpdateStatusBar(
 	    return;
 
 	/* Format the status bar message */
-	if((info == EDV_DND_TYPE_INFO_TEXT_PLAIN) ||
-	   (info == EDV_DND_TYPE_INFO_TEXT_URI_LIST) ||
-	   (info == EDV_DND_TYPE_INFO_STRING)
+	if((info == EDV_DND_INFO_TEXT_PLAIN) ||
+	   (info == EDV_DND_INFO_TEXT_URI_LIST) ||
+	   (info == EDV_DND_INFO_STRING)
 	)
 	{
 	    switch(gdk_action)
@@ -202,11 +202,11 @@ static void EDVArchiverDNDUpdateStatusBar(
 		break;
 	    }
 	}
-	else if(info == EDV_DND_TYPE_INFO_RECYCLED_OBJECT)
+	else if(info == EDV_DND_INFO_RECYCLED_OBJECT)
 	{
 	    /* Recycled objects may not be added to an archive */
 	}
-	else if(info == EDV_DND_TYPE_INFO_ARCHIVE_OBJECT)
+	else if(info == EDV_DND_INFO_ARCHIVE_OBJECT)
 	{
 	    /* Objects in archives are already in the archive */
 	}
@@ -364,9 +364,9 @@ current archive?\n"
 	);
 	/* User confirmed and dnd target type is a disk object? */
 	if((initial_confirmation_result == CDIALOG_RESPONSE_YES) &&
-	   ((info == EDV_DND_TYPE_INFO_TEXT_PLAIN) ||
-	    (info == EDV_DND_TYPE_INFO_TEXT_URI_LIST) ||
-	    (info == EDV_DND_TYPE_INFO_STRING)
+	   ((info == EDV_DND_INFO_TEXT_PLAIN) ||
+	    (info == EDV_DND_INFO_TEXT_URI_LIST) ||
+	    (info == EDV_DND_INFO_STRING)
 	   )
 	)
 	{
@@ -545,14 +545,14 @@ current archive?\n"
 	}
 	/* User confirmed and dnd target type is a recycled object? */
 	else if((initial_confirmation_result == CDIALOG_RESPONSE_YES) &&
-		(info == EDV_DND_TYPE_INFO_RECYCLED_OBJECT)
+		(info == EDV_DND_INFO_RECYCLED_OBJECT)
 	)
 	{
 	    /* Recycled objects may not be added to an archive */
 	}
 	/* User confirmed and dnd target type is an archive object? */
 	else if((initial_confirmation_result == CDIALOG_RESPONSE_YES) &&
-		(info == EDV_DND_TYPE_INFO_ARCHIVE_OBJECT)
+		(info == EDV_DND_INFO_ARCHIVE_OBJECT)
 	)
 	{
 	    /* Archive objects may not be added back into an archive */
