@@ -114,7 +114,7 @@ static void EDVBrowserContentsSetCellDevice(
 	GtkCList *clist, edv_object_struct *obj,
 	const gint row, const gint column
 );
-static void EDVBrowserContentsSetCellINode(
+static void EDVBrowserContentsSetCellIndex(
 	edv_core_struct *core, edv_browser_struct *browser,
 	GtkCList *clist, edv_object_struct *obj,
 	const gint row, const gint column
@@ -156,6 +156,10 @@ static void EDVBrowserContentsAppendListing(
 GList *EDVBrowserContentsGetSelectedPaths(edv_browser_struct *browser);
 
 /* Finding */
+gint EDVBrowserContentsFindRowByIndex(
+	edv_browser_struct *browser,
+	const gulong device_index, const gulong index
+);
 gint EDVBrowserContentsFindRowByPath(
 	edv_browser_struct *browser, const gchar *path
 );
@@ -268,7 +272,7 @@ static void EDVBrowserContentsResetColumns(
 {
 	gint i, width;
 	const gchar *title = NULL;
-	GList *glist;             
+	GList *glist;
 	GtkJustification justify = GTK_JUSTIFY_LEFT;
 	GtkRcStyle *lists_rcstyle = core->lists_rcstyle;
 	cfg_intlist_struct	*column_types_intlist,
@@ -370,12 +374,12 @@ static void EDVBrowserContentsResetColumns(
 		title = "Linked To";
 		justify = GTK_JUSTIFY_LEFT;
 		break;
-	      case EDV_BROWSER_COLUMN_TYPE_DEVICE:
-		title = "Device";
+	      case EDV_BROWSER_COLUMN_TYPE_DEVICE_INDEX:
+		title = "Device Index";
 		justify = GTK_JUSTIFY_RIGHT;
 		break;
-	      case EDV_BROWSER_COLUMN_TYPE_INODE:
-		title = "INode";
+	      case EDV_BROWSER_COLUMN_TYPE_INDEX:
+		title = "Index";
 		justify = GTK_JUSTIFY_RIGHT;
 		break;
 	      case EDV_BROWSER_COLUMN_TYPE_DEVICE_TYPE:
@@ -1107,7 +1111,8 @@ static void EDVBrowserContentsSetCellLinkedTo(
 }
 
 /*
- *      Sets the object device for the specified cell on the given clist.
+ *	Sets the object's device index or the specified cell on
+ *	the given clist.
  */
 static void EDVBrowserContentsSetCellDevice(
 	edv_core_struct *core, edv_browser_struct *browser,
@@ -1122,7 +1127,7 @@ static void EDVBrowserContentsSetCellDevice(
 	g_snprintf(
 	    num_str, sizeof(num_str),
 	    "%ld",
-	    obj->device
+	    obj->device_index
 	);
 
 	/* Set cell */
@@ -1136,9 +1141,9 @@ static void EDVBrowserContentsSetCellDevice(
 }
 
 /*
- *      Sets the object inode for the specified cell on the given clist.
+ *	Sets the object's index for the specified cell on the given clist.
  */
-static void EDVBrowserContentsSetCellINode(
+static void EDVBrowserContentsSetCellIndex(
 	edv_core_struct *core, edv_browser_struct *browser,
 	GtkCList *clist, edv_object_struct *obj,
 	const gint row, const gint column
@@ -1147,11 +1152,10 @@ static void EDVBrowserContentsSetCellINode(
 	const gint border_minor = 2;
 	gchar num_str[80];
 
-	/* Get string for inode */
 	g_snprintf(
 	    num_str, sizeof(num_str),
 	    "%ld",
-	    obj->inode
+	    obj->index
 	);
 
 	/* Set cell */
@@ -1384,14 +1388,14 @@ static void EDVBrowserContentsSetRow(
 		    row, i
 		);
 		break;
-	      case EDV_BROWSER_COLUMN_TYPE_DEVICE:
+	      case EDV_BROWSER_COLUMN_TYPE_DEVICE_INDEX:
 		EDVBrowserContentsSetCellDevice(
 		    core, browser, clist, obj,
 		    row, i
 		);
 		break;
-	      case EDV_BROWSER_COLUMN_TYPE_INODE:
-		EDVBrowserContentsSetCellINode(
+	      case EDV_BROWSER_COLUMN_TYPE_INDEX:
+		EDVBrowserContentsSetCellIndex(
 		    core, browser, clist, obj,
 		    row, i
 		);
@@ -1855,10 +1859,54 @@ GList *EDVBrowserContentsGetSelectedPaths(edv_browser_struct *browser)
 
 
 /*
- *	Returns the row index of the Contents List that contains a disk
- *	object structure who's path matches the given path.
+ *	Finds the row who's object matches the location index.
  *
- *	Can return -1 on failed match.
+ *	The device_index specifies the index of the device that the
+ *	object resides on.
+ *
+ *	The index specifies the index on the device that the object
+ *	resides at.
+ *
+ *	Returns the matched row or -1 on error.
+ */
+gint EDVBrowserContentsFindRowByIndex(
+	edv_browser_struct *browser, 
+	const gulong device_index, const gulong index
+)
+{
+	gint i;
+	GtkCList *clist;
+	edv_object_struct *obj;
+
+	if(browser == NULL)
+	    return(-1);
+
+	clist = (GtkCList *)browser->contents_clist;
+	if(clist == NULL)
+	    return(-1);
+
+	/* Iterate through all rows */
+	for(i = 0; i < clist->rows; i++)
+	{
+	    obj = EDV_OBJECT(gtk_clist_get_row_data(clist, i));
+	    if(obj == NULL)
+		continue;
+
+	    if((obj->device_index == device_index) &&
+	       (obj->index == index)
+	    )
+		return(i);
+	}
+
+	return(-1);
+}
+
+/*
+ *	Finds the row who's object matches the path.
+ *
+ *	The path specifies the full path of the object.
+ *
+ *	Returns the matched row or -1 on error.
  */
 gint EDVBrowserContentsFindRowByPath(
 	edv_browser_struct *browser, const gchar *path
@@ -2246,16 +2294,18 @@ static void EDVBrowserContentsFPromptRenameApplyCB(
 	    if((obj != NULL) ? (obj->full_path != NULL) : FALSE)
 	    {
 		gboolean yes_to_all = FALSE;
-		gint status;
 		const gchar *error_msg;
-		gchar	*old_full_path = STRDUP(obj->full_path),
-			*new_obj = NULL;
+		gchar *old_full_path = STRDUP(obj->full_path);
+		GList *modified_paths_list;
 
-		/* Perform rename */
-		status = EDVObjectOPRename(
-		    core, old_full_path, value,
-		    &new_obj, toplevel,
-		    FALSE, TRUE,
+		/* Rename */
+		EDVObjectOPRename(
+		    core,
+		    old_full_path, value,
+		    &modified_paths_list,
+		    toplevel,
+		    FALSE,			/* Do not show progress */
+		    TRUE,			/* Interactive */
 		    &yes_to_all
 		);
 
@@ -2280,35 +2330,49 @@ static void EDVBrowserContentsFPromptRenameApplyCB(
 		    );
 		}
 
-		/* Got new object full path name (implying success)? */
-		if((new_obj != NULL) && (old_full_path != NULL))
+		/* Report the modified objects */
+		if(modified_paths_list != NULL)
 		{
 		    struct stat lstat_buf;
-		    const gchar	*new_child = g_basename(new_obj),
-				*old_child = g_basename(old_full_path); 
+		    const gchar *modified_path;
+		    GList *glist;
 
-		    /* Get new local statistics for the renamed object */
-		    if(!lstat((const char *)new_obj, &lstat_buf))
+		    for(glist = modified_paths_list;
+			glist != NULL;
+			glist = g_list_next(glist)
+		    )
 		    {
-			gchar *buf = g_strdup_printf(
-			    "Object \"%s\" renamed to \"%s\"",
-			    old_child, new_child
-			);
-			EDVStatusBarMessage(
-			    browser->status_bar, buf, FALSE
-			);
-			g_free(buf);
+			modified_path = (const gchar *)glist->data;
+			if(modified_path == NULL)
+			    continue;
 
-			/* Emit object modified signal to all windows */
-			EDVObjectModifiedEmit(
-			    core, old_full_path,
-			    new_obj, &lstat_buf
-			);
+			if(!lstat(modified_path, &lstat_buf))
+			{
+			    gchar *s = g_strdup_printf(
+				"Object \"%s\" renamed to \"%s\"",
+				g_basename(old_full_path),
+				g_basename(modified_path)
+			    );
+			    EDVStatusBarMessage(browser->status_bar, s, FALSE);
+			    g_free(s);
+
+			    EDVObjectModifiedEmit(
+				core,
+				old_full_path,
+				modified_path,
+				&lstat_buf
+			    );
+			}
 		    }
+
+		    g_list_foreach(modified_paths_list, (GFunc)g_free, NULL);
+		    g_list_free(modified_paths_list);
 		}
 		else
-		{
-		    /* Rename failed */
+		{   
+		    /* Did not get the modified object path so this
+		     * implies failure
+		     */
 		    EDVStatusBarMessage(
 			browser->status_bar,
 			"Rename object failed",
@@ -2316,15 +2380,6 @@ static void EDVBrowserContentsFPromptRenameApplyCB(
 		    );
 		}
 
-#if 0
-		/* The disk object structure may now be invalid if the
-		 * object modified signal was emitted
-		 */
-		object = NULL;
-#endif
-
-		/* Delete coppies of paths */
-		g_free(new_obj);
 		g_free(old_full_path);
 	    }
 	}
@@ -2411,7 +2466,7 @@ void EDVBrowserContentsDoFPromptRename(
 	    clist->clist_window, &px, &py
 	);
 	px += cx + 0;
-	py += cy - 2;   /* Move up a little */
+	py += cy - 2;		/* Move up a little */
 
 	/* Get object from the specified row on the Contents List */
 	obj = EDV_OBJECT(gtk_clist_get_row_data(clist, row));
@@ -2511,15 +2566,15 @@ void EDVBrowserContentsObjectAddedNotify(
 	    return;
 	}
 
-	/* Check if the path of the added object describes an object
-	 * that is already in the list
-	 */
-	row = EDVBrowserContentsFindRowByPath(browser, path);
-	if((row >= 0) && (row < clist->rows))
+	/* Check if the added object is already listed */
+	row = EDVBrowserContentsFindRowByIndex(
+	    browser,
+	    (gulong)lstat_buf->st_dev,
+	    (gulong)lstat_buf->st_ino
+	);
+	if(row > -1)
 	{
-	    /* The new object to add already exists in the list, so just
-	     * update the object
-	     */
+	    /* The object is already listed, update it */
 	    edv_object_struct *obj = EDV_OBJECT(
 		gtk_clist_get_row_data(clist, row)
 	    );
@@ -2614,8 +2669,12 @@ void EDVBrowserContentsObjectModifiedNotify(
 	else if(!strcmp(parent_path, cur_path))
 	{
 	    /* Update the existing object */
-	    const gint row = EDVBrowserContentsFindRowByPath(browser, path);
-	    if((row >= 0) && (row < clist->rows))
+	    const gint row = EDVBrowserContentsFindRowByIndex(
+		browser,
+		(gulong)lstat_buf->st_dev,
+		(gulong)lstat_buf->st_ino
+	    );
+	    if(row > -1)
 	    {
 		/* Update this object */
 		edv_object_struct *obj = EDV_OBJECT(
@@ -2623,7 +2682,7 @@ void EDVBrowserContentsObjectModifiedNotify(
 		);
 		if(obj != NULL)
 		{
-		    EDVObjectSetPath(obj, new_path);		/* Use new_path */
+		    EDVObjectSetPath(obj, new_path);	/* Use new_path */
 		    EDVObjectSetStat(obj, lstat_buf);
 		    EDVObjectUpdateLinkFlags(obj);
 
@@ -2683,8 +2742,11 @@ void EDVBrowserContentsObjectRemovedNotify(
 	else if(!strcmp(parent_path, cur_path))
 	{
 	    /* Remove the existing object */
-	    const gint row = EDVBrowserContentsFindRowByPath(browser, path);
-	    if((row >= 0) && (row < clist->rows))
+	    const gint row = EDVBrowserContentsFindRowByPath(
+		browser,
+		path
+	    );
+	    if(row > -1)
 		gtk_clist_remove(clist, row);
 	}
 
