@@ -121,9 +121,9 @@ static void EDVBrowserDNDUpdateStatusBar(
 	    return;
 
 	/* Format the status bar message */
-	if((info == EDV_DND_TYPE_INFO_TEXT_PLAIN) ||
-	   (info == EDV_DND_TYPE_INFO_TEXT_URI_LIST) ||
-	   (info == EDV_DND_TYPE_INFO_STRING)
+	if((info == EDV_DND_INFO_TEXT_PLAIN) ||
+	   (info == EDV_DND_INFO_TEXT_URI_LIST) ||
+	   (info == EDV_DND_INFO_STRING)
 	)
 	{
 	    switch(gdk_action)
@@ -181,7 +181,7 @@ static void EDVBrowserDNDUpdateStatusBar(
 		break;
 	    }
 	}
-	else if(info == EDV_DND_TYPE_INFO_RECYCLED_OBJECT)
+	else if(info == EDV_DND_INFO_RECYCLED_OBJECT)
 	{
 	    switch(gdk_action)
 	    {
@@ -206,7 +206,7 @@ static void EDVBrowserDNDUpdateStatusBar(
 		break;
 	    }
 	}
-	else if(info == EDV_DND_TYPE_INFO_ARCHIVE_OBJECT)
+	else if(info == EDV_DND_INFO_ARCHIVE_OBJECT)
 	{
 	    switch(gdk_action)
 	    {
@@ -308,7 +308,7 @@ static void EDVBrowserDragDataReceivedNexus(
 	 * that have a url with a http or ftp protocol
 	 */
 	url = (url_list != NULL) ? URL(url_list->data) : NULL;
-	if((url != NULL) ? !STRISEMPTY(url->path) : FALSE)
+	if((url != NULL) ? !STRISEMPTY(url->protocol) : FALSE)
 	{
 	    const gchar *protocol = url->protocol;
 	    if(!g_strcasecmp(protocol, "http") ||
@@ -337,9 +337,9 @@ static void EDVBrowserDragDataReceivedNexus(
 	);
 	/* Regular Object? */
 	if((initial_confirmation_result == CDIALOG_RESPONSE_YES) &&
-	   ((info == EDV_DND_TYPE_INFO_TEXT_PLAIN) ||
-	    (info == EDV_DND_TYPE_INFO_TEXT_URI_LIST) ||
-	    (info == EDV_DND_TYPE_INFO_STRING)
+	   ((info == EDV_DND_INFO_TEXT_PLAIN) ||
+	    (info == EDV_DND_INFO_TEXT_URI_LIST) ||
+	    (info == EDV_DND_INFO_STRING)
 	   )
 	)
 	{
@@ -481,7 +481,7 @@ static void EDVBrowserDragDataReceivedNexus(
 	}
 	/* Recycled Object? */
 	else if((initial_confirmation_result == CDIALOG_RESPONSE_YES) &&
-		(info == EDV_DND_TYPE_INFO_RECYCLED_OBJECT)
+		(info == EDV_DND_INFO_RECYCLED_OBJECT)
 	)
 	{
 	    struct stat lstat_buf;
@@ -594,7 +594,7 @@ static void EDVBrowserDragDataReceivedNexus(
 	}
 	/* Archive Object? */
 	else if((initial_confirmation_result == CDIALOG_RESPONSE_YES) &&
-		(info == EDV_DND_TYPE_INFO_ARCHIVE_OBJECT)
+		(info == EDV_DND_INFO_ARCHIVE_OBJECT)
 	)
 	{
 	    gboolean	yes_to_all = FALSE;
