@@ -27,32 +27,32 @@
  */
 #define PROG_NAME			"Endeavour"
 #define PROG_NAME_FULL			"Endeavour Mark II"
-#define PROG_VERSION			"2.7.3"
+#define PROG_VERSION			"2.7.5"
 
 #define PROG_VERSION_MAJOR		2
 #define PROG_VERSION_MINOR		7
-#define PROG_VERSION_RELEASE		3
+#define PROG_VERSION_RELEASE		5
 
 /*
  *      Copyright message:
  */
 #if defined(PROG_LANGUAGE_SPANISH)
 #define PROG_COPYRIGHT	"\
-El derecho de autor (C) 1997-2006 WolfPack Entertainment.\n\
+El derecho de autor (C) 1997-2007 WolfPack Entertainment.\n\
 Este programa es protegido por leyes internacionales de derecho de autor\n\
 y tratados, la distribucin y/o la modificacin de este software en la\n\
 infraccin de la Licencia del Pblico de GNU se prohiben estrictamente.\n\
 Violators ser procesado a la extensin ms repleta de la ley.\n"
 #elif defined(PROG_LANGUAGE_FRENCH)
 #define PROG_COPYRIGHT  "\
-Dposer (C) 1997-2006 WolfPack Entertainment.\n\
+Dposer (C) 1997-2007 WolfPack Entertainment.\n\
 Ce programme est protg par international dpose lois et traits, \n\
 distribution et/ou de ce logiciel dans violation du GNU Public Permis\n\
 strictement est interdit. Violators sera poursuivi  l'tendue plus pleine\n\
 de la loi.\n"
 #elif defined(PROG_LANGUAGE_GERMAN)
 #define PROG_COPYRIGHT  "\
-Urheberrecht (C) 1997-2006 WolfPack Entertainment.\n\
+Urheberrecht (C) 1997-2007 WolfPack Entertainment.\n\
 Dieses Programm wird von internationalem Urheberrecht Gesetzen und\n\
 Vertrgen, Austeilung bzw. nderung dieser Software in bertretung\n\
 DER GNU ffentlichkeit Erlaubnis streng verboten wird geschtzt.\n\
@@ -60,35 +60,35 @@ Verletzer werden zum vollsten Umfang des Gesetzes strafrechtlich\n\
 verfolgt werden.\n"
 #elif defined(PROG_LANGUAGE_ITALIAN)
 #define PROG_COPYRIGHT  "\
-Il copyright (C) 1997-2006 WolfPack Entertainment.\n\
+Il copyright (C) 1997-2007 WolfPack Entertainment.\n\
 Questo programma  protetto dalle leggi di copyright internazionali e\n\
 dai trattati, la distribuzione e/o la modifica di questo software nella\n\
 violazione dello GNU la Licenza Pubblica  strettamente proibita. Il\n\
 Violators sar perseguito all'estensione la pi piena della legge.\n"
 #elif defined(PROG_LANGUAGE_DUTCH)
 #define PROG_COPYRIGHT  "\
-Auteursrecht (C) 1997-2006 WolfPack Entertainment.\n\
+Auteursrecht (C) 1997-2007 WolfPack Entertainment.\n\
 Deze programma wordt door internationale auteursrecht wetten en\n\
 verdragen, verdeling en/of wijziging van deze software in overtreding\n\
 van de GNU Publiek Vergunning strikt verboden wordt beschermd.\n\
 Overtreders zullen te de volste omvang van de wet geprocedeerd worden.\n"
 #elif defined(PROG_LANGUAGE_PORTUGUESE)
 #define PROG_COPYRIGHT  "\
-Os direitos autorais (C) 1997-2006 WolfPack Entertainment.\n\
+Os direitos autorais (C) 1997-2007 WolfPack Entertainment.\n\
 Este programa  protegido por direitos internacionais leis autorais e\n\
 tratados, modificao de e/ou de distribuio deste software em infrao\n\
 do GNU Licena Pblica precisamente  proibida. O Violators ser\n\
 processado  plena extenso da lei.\n"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 #define PROG_COPYRIGHT  "\
-Copyright (C) 1997-2006 WolfPack Entertainment.\n\
+Copyright (C) 1997-2007 WolfPack Entertainment.\n\
 Dette programet beskytter av internasjonal copyrightlover og traktater,\n\
 distribusjon og/eller modifikasjon av denne programvaren i overtredelse\n\
 av GNU Public License er streng forbudt. Violators tiltalt til den\n\
 fulleste omfang av loven.\n"
 #else
 #define PROG_COPYRIGHT  "\
-Copyright (C) 1997-2006 WolfPack Entertainment.\n\
+Copyright (C) 1997-2007 WolfPack Entertainment.\n\
 This program is protected by international copyright laws and treaties,\n\
 distribution and/or modification of this software in violation of the\n\
 GNU Public License is strictly prohibited. Violators will be prosecuted\n\
@@ -633,15 +633,15 @@ to the fullest extent of the law.\n"
 /*
  *	Drag & Drop Target Type Names & Info Values:
  */
-#define EDV_DND_TYPE_INFO_TEXT_PLAIN		0	/* "text/plain" */
-#define EDV_DND_TYPE_INFO_TEXT_URI_LIST		1	/* "text/uri-list" */
-#define EDV_DND_TYPE_INFO_STRING		2	/* "STRING" */
+#define EDV_DND_INFO_TEXT_PLAIN		0	/* "text/plain" */
+#define EDV_DND_INFO_TEXT_URI_LIST	1	/* "text/uri-list" */
+#define EDV_DND_INFO_STRING		2	/* "STRING" */
 
-#define EDV_DND_TYPE_INFO_RECYCLED_OBJECT	3
-#define EDV_DND_TYPE_STRING_RECYCLED_OBJECT	"endeavour_recycled_object"
+#define EDV_DND_INFO_RECYCLED_OBJECT	3
+#define EDV_DND_TARGET_RECYCLED_OBJECT	"Endeavour2/RecycledObject"
 
-#define EDV_DND_TYPE_INFO_ARCHIVE_OBJECT	4
-#define EDV_DND_TYPE_STRING_ARCHIVE_OBJECT	"endeavour_archive_object"
+#define EDV_DND_INFO_ARCHIVE_OBJECT	4
+#define EDV_DND_TARGET_ARCHIVE_OBJECT	"Endeavour2/ArchiveObject"
 
 
 /*
