@@ -8,6 +8,7 @@
 
 #include "guiutils.h"
 #include "cdialog.h"
+#include "progressdialog.h"
 
 #include "edv_types.h"
 #include "edv_list_cb.h"
@@ -36,12 +37,20 @@
 #include "images/icon_fsck_20x20.xpm"
 #include "images/icon_tools_20x20.xpm"
 #include "images/icon_floppy_20x20.xpm"
+
+#include "images/icon_devices_list_32x32.xpm"
 #include "images/icon_devices_list_48x48.xpm"
+
 #if 0
 #include "images/icon_mounted_20x20.xpm"
 #include "images/icon_not_mounted_20x20.xpm"
 #endif
 
+
+static gint EDVDevicesListProgressCB(
+	gpointer data, const gulong pos, const gulong max
+);
+
 static gint EDVDevicesListWinDeleteEventCB(
 	GtkWidget *widget, GdkEvent *event, gpointer data
 );
@@ -82,7 +91,10 @@ void EDVDevicesListWinSetRow(
 	edv_devices_list_win_struct *lw,
 	const gint row, edv_device_struct *dev
 );
-void EDVDevicesListWinFetchValues(edv_devices_list_win_struct *lw);
+void EDVDevicesListWinFetchValues(
+	edv_devices_list_win_struct *lw,
+	const gboolean verbose
+);
 
 void EDVDevicesListWinUsageChangedCB(
 	edv_devices_list_win_struct *lw
@@ -164,6 +176,39 @@ void EDVDevicesListWinDelete(
 #define LISTWIN_HEIGHT		460
 
 
+/*
+ *	Devices List Window Progress callback.
+ */
+static gint EDVDevicesListProgressCB(
+	gpointer data, const gulong pos, const gulong max
+)
+{
+	edv_devices_list_win_struct *lw = EDV_DEVICE_LISTWIN(data);
+	if(lw == NULL)
+	    return(1);
+
+	if(ProgressDialogIsQuery())
+	{
+	    if(ProgressDialogStopCount() > 0)
+		return(1);
+
+	    if(max > 0l)
+		ProgressDialogUpdate(
+		    NULL, NULL, NULL, NULL,
+		    (gfloat)pos / (gfloat)max,
+		    EDV_DEF_PROGRESS_BAR_TICKS, TRUE
+		);
+	    else
+		ProgressDialogUpdateUnknown(
+		    NULL, NULL, NULL, NULL,
+		    TRUE
+		);
+	}
+
+	return(0);
+}
+
+
 /*
  *	Devices List Window GtkWindow "delete_event" signal callback.
  */
@@ -2167,32 +2212,51 @@ void EDVDevicesListWinSetRow(
  *	Gets the Devices List Window's list of devices from the
  *	devices list.
  */
-void EDVDevicesListWinFetchValues(edv_devices_list_win_struct *lw)
+void EDVDevicesListWinFetchValues(
+	edv_devices_list_win_struct *lw,
+	const gboolean verbose
+)
 {
-	gint i, row;
+	gint i, ndevices, row, ncolumns, progress_update_mod;
 	gchar **strv;
+	GtkWidget *toplevel;
 	GtkCList *clist;
-	edv_core_struct *core;
 	edv_device_struct *dev;
+	edv_core_struct *core;
 
 	if(lw == NULL)
 	    return;
 
+	if(verbose && ProgressDialogIsQuery())
+	    return;
+
+	toplevel = lw->toplevel;
 	clist = (GtkCList *)lw->devices_clist;
 	core = lw->core;
 	if((clist == NULL) || (core == NULL))
 	    return;
 
-	if(clist->columns < 1)
+	ncolumns = clist->columns;
+	if(ncolumns < 1)
 	    return;
 
-	/* Allocate the GtkCList row cell values */
-	strv = (gchar **)g_malloc(clist->columns * sizeof(gchar *));
-	for(i = 0; i < clist->columns; i++)
+	/* Allocate the row cell values */
+	strv = (gchar **)g_malloc(ncolumns * sizeof(gchar *));
+	for(i = 0; i < ncolumns; i++)
 	    strv[i] = "";
 
-
-	/* Begin updating */
+	/* Map the progress dialog? */
+	if(verbose)
+	{
+	    ProgressDialogSetTransientFor(toplevel);
+	    ProgressDialogMap(
+		"Loading Devices",
+		"Loading Devices...",
+		(const guint8 **)icon_devices_list_32x32_xpm,
+		"Stop"
+	    );
+	    gdk_flush();
+	}
 
 	gtk_clist_freeze(clist);
 
@@ -2203,14 +2267,28 @@ void EDVDevicesListWinFetchValues(edv_devices_list_win_struct *lw)
 	/* Iterate through the devices list and append each device
 	 * to the GtkCList
 	 */
-	for(i = 0; i < core->total_devices; i++)
+	ndevices = core->total_devices;
+	progress_update_mod = MAX(ndevices / 100, 1);
+	for(i = 0; i < ndevices; i++)
 	{
 	    dev = core->device[i];
 	    if(dev == NULL)
 		continue;
 
 	    row = gtk_clist_append(clist, strv);
+	    if(row < 0)
+		break;
+
 	    EDVDevicesListWinSetRow(lw, row, dev);
+
+	    /* Report progress and check for user abort */
+	    if(verbose && ((i % progress_update_mod) == 0))
+	    {
+		if(EDVDevicesListProgressCB(
+		    lw, (gulong)(i + 1), (gulong)ndevices
+		))
+		    break;
+	    }
 	}
 
 	gtk_clist_thaw(clist);
@@ -2218,6 +2296,13 @@ void EDVDevicesListWinFetchValues(edv_devices_list_win_struct *lw)
 	g_free(strv);
 
 	EDVDevicesListWinUpdateMenus(lw);
+
+	/* Unmap the progress dialog? */
+	if(verbose)
+	{
+	    ProgressDialogBreakQuery(TRUE);
+	    ProgressDialogSetTransientFor(NULL);
+	}
 }
 
 
@@ -2233,17 +2318,17 @@ void EDVDevicesListWinUsageChangedCB(
 	edv_device_struct *dev;
 	edv_core_struct *core;
 
-        if(lw == NULL)
-            return;
+	if(lw == NULL)
+	    return;
 
 	/* Skip if the devices list is not mapped */
 	if(!EDVDevicesListWinIsMapped(lw))
 	    return;
 
 	clist = (GtkCList *)lw->devices_clist;
-        core = lw->core;
-        if((clist == NULL) || (core == NULL))
-            return;
+	core = lw->core;
+	if((clist == NULL) || (core == NULL))
+	    return;
 
 	/* Get the selected device */
 	sel_dev_num = EDVCListGetSelectedLast(clist, NULL);
