@@ -13,6 +13,7 @@
 #include "../../include/prochandle.h"
 
 #include "../guiutils.h"
+#include "../fprompt.h"
 #include "../cdialog.h"
 #include "../pdialog.h"
 #include "../fb.h"
@@ -1338,10 +1339,11 @@ int main(int argc, char *argv[])
 					\
  if(initialized_gtk) {			\
   /* Shutdown dialogs */		\
-  CDialogShutdown();			\
   PDialogShutdown();			\
   FileBrowserShutdown();		\
   ProgressDialogShutdown();		\
+  CDialogShutdown();			\
+  FPromptShutdown();			\
 					\
   /* Reset the DND Icon */		\
   GUIDNDSetDragIcon(NULL, NULL, 0, 0);	\
@@ -1587,6 +1589,7 @@ int main(int argc, char *argv[])
 	gdk_rgb_init();
 
 	/* Initialize dialogs */
+	FPromptInit();
 	CDialogInit();
 	PDialogInit();
 	FileBrowserInit();
