@@ -2492,7 +2492,9 @@ To:\n\
 	    parent = g_dirname(tar_path);
 	    if(parent != NULL)
 	    {
-		if(lstat((const char *)parent, &stat_buf))
+		const gint	stat_status = lstat((const char *)parent, &stat_buf),
+				error_code = errno;
+		if((stat_status != 0) && (error_code == ENOENT))
 		{
 		    /* Create each parent directory(ies) and add
 		     * them to the list of extracted objects
@@ -2946,7 +2948,9 @@ To:\n\
 	    parent = g_dirname(tar_path);
 	    if(parent != NULL)
 	    {
-		if(lstat((const char *)parent, &stat_buf))
+		const gint	stat_status = lstat((const char *)parent, &stat_buf),
+				error_code = errno;
+		if((stat_status != 0) && (error_code == ENOENT))
 		{
 		    /* Create each parent directory(ies) and add
 		     * them to the list of extracted objects
