@@ -1351,9 +1351,9 @@ void EDVEntryDragDataReceivedCB(
 	}
 
 	/* Drag data is a disk object path? */
-	if((info == EDV_DND_TYPE_INFO_TEXT_PLAIN) ||
-	   (info == EDV_DND_TYPE_INFO_TEXT_URI_LIST) ||
-	   (info == EDV_DND_TYPE_INFO_STRING)
+	if((info == EDV_DND_INFO_TEXT_PLAIN) ||
+	   (info == EDV_DND_INFO_TEXT_URI_LIST) ||
+	   (info == EDV_DND_INFO_STRING)
 	)
 	{
 	    gchar *s = STRDUP("");
