@@ -1765,9 +1765,9 @@ gint EDVConfirmDND(
 	/* Handle by drag context target type */
 
 	/* Disk object? */
-	if((info == EDV_DND_TYPE_INFO_TEXT_PLAIN) ||
-	   (info == EDV_DND_TYPE_INFO_TEXT_URI_LIST) ||
-	   (info == EDV_DND_TYPE_INFO_STRING)
+	if((info == EDV_DND_INFO_TEXT_PLAIN) ||
+	   (info == EDV_DND_INFO_TEXT_URI_LIST) ||
+	   (info == EDV_DND_INFO_STRING)
 	)
 	{
 	    switch(gdk_action)
@@ -1793,7 +1793,7 @@ gint EDVConfirmDND(
 	    }
 	}
 	/* Recycled object? */
-	else if(info == EDV_DND_TYPE_INFO_RECYCLED_OBJECT)
+	else if(info == EDV_DND_INFO_RECYCLED_OBJECT)
 	{
 	    switch(gdk_action)
 	    {
@@ -1816,7 +1816,7 @@ gint EDVConfirmDND(
 	    }
 	}
 	/* Archive object? */
-	else if(info == EDV_DND_TYPE_INFO_ARCHIVE_OBJECT)
+	else if(info == EDV_DND_INFO_ARCHIVE_OBJECT)
 	{
 	    switch(gdk_action)
 	    {
