@@ -1227,6 +1227,13 @@ edv_core_struct *EDVNew(gint argc, gchar *argv[], gint *error_rtn)
 	core->cfg_file = NULL;
 	core->cfg_list = NULL;
 
+	core->data_type_recycled_object_atom = gdk_atom_intern(
+	    EDV_DND_TARGET_RECYCLED_OBJECT, FALSE
+	);
+	core->data_type_archive_object_atom = gdk_atom_intern(
+	    EDV_DND_TARGET_ARCHIVE_OBJECT, FALSE
+	);
+
 	core->pixmap_list = NULL;
 
 	core->browser = NULL;
