@@ -410,7 +410,7 @@ gint EDVNewWindow(
 	else if(!g_strcasecmp(dname, "about_dialog") ||
 		!g_strcasecmp(dname, "about_dlg") ||
 		!g_strcasecmp(dname, "aboutdlg") ||
-                !g_strcasecmp(dname, "about")
+		!g_strcasecmp(dname, "about")
 	)
 	{
 	    EDVAboutPage(core, extra, NULL);
@@ -1467,7 +1467,6 @@ void EDVMapDevicesListWin(
 {
 	edv_devices_list_win_struct *lw;
 
-
 	if(core == NULL)
 	    return;
 
@@ -1483,7 +1482,7 @@ void EDVMapDevicesListWin(
 	EDVCenterWindowToWindow(toplevel, lw->toplevel);
 	EDVDevicesListSetBusy(lw, TRUE);
 	EDVDevicesListWinMap(lw);
-	EDVDevicesListWinFetchValues(lw);
+	EDVDevicesListWinFetchValues(lw, TRUE);
 	EDVDevicesListSetBusy(lw, FALSE);
 }
 
@@ -1516,7 +1515,7 @@ void EDVMapMIMETypesListWin(
 	EDVCenterWindowToWindow(toplevel, lw->toplevel);
 	EDVMimeTypesListWinSetBusy(lw, TRUE);
 	EDVMimeTypesListWinMap(lw);
-	EDVMimeTypesListWinFetchValues(lw);
+	EDVMimeTypesListWinFetchValues(lw, TRUE);
 	if(type != NULL)
 	    EDVMimeTypesListWinSelectByType(lw, type);
 	EDVMimeTypesListWinSetBusy(lw, FALSE);
@@ -2372,14 +2371,14 @@ void EDVRefresh(edv_core_struct *core)
 	device_list = core->device_listwin;
 	if(EDVDevicesListWinIsMapped(device_list))
 	{
-	    EDVDevicesListWinFetchValues(device_list);
+	    EDVDevicesListWinFetchValues(device_list, FALSE);
 	}
 
 	/* MIME Types List */
 	mimetype_list = core->mimetype_listwin;
 	if(EDVMimeTypesListWinIsMapped(mimetype_list))
 	{
-	    EDVMimeTypesListWinFetchValues(mimetype_list);
+	    EDVMimeTypesListWinFetchValues(mimetype_list, FALSE);
 	}
 
 	/* Options Window */
