@@ -1,5 +1,6 @@
 #include <stdlib.h>
 #include <string.h>
+#include <sys/types.h>
 #include <sys/stat.h>
 #include <gtk/gtk.h>
 #include <unistd.h>
@@ -118,23 +119,34 @@ static gchar *EDVOpenStripExt(const gchar *s)
  */
 static gboolean EDVOpenIsFileExecutable(const gchar *path)
 {
+	mode_t m;
 	struct stat stat_buf;
 
 	if(STRISEMPTY(path))
 	    return(FALSE);
 
-	/* Get destination stats */
+	/* Get the destination stats */
 	if(stat(path, &stat_buf))
 	    return(FALSE);
 
+	m = stat_buf.st_mode;
+
 #ifdef S_ISREG
 	/* Does the path lead to a file? */
-	if(!S_ISREG(stat_buf.st_mode))
+	if(!S_ISREG(m))
 	    return(FALSE);
 #endif
 
+#if defined(S_IXUSR) && defined(S_IXGRP) && defined(S_IXOTH)
 	/* Is this file executable? */
-	return(!access(path, X_OK) ? TRUE : FALSE);
+	if((m & S_IXUSR) ||
+	   (m & S_IXGRP) ||
+	   (m & S_IXOTH)
+	)
+	    return(TRUE);
+#endif
+
+	return(FALSE);
 }
 
 /*
@@ -421,17 +433,17 @@ static gint EDVOpenIteration(
 		gint pid;
 		gchar *parent, *cmd;
 
-		/* Record previous working dir */
+		/* Record the previous working dir */
 		gchar *pwd = EDVGetCWD();
 
-		/* Set new working dir as the parent of the specified
-		 * path
+		/* Set the new working dir as the parent of the
+		 * specified path
 		 */
 		parent = g_dirname(path);
 		EDVSetCWD(parent);
 		g_free(parent);
 
-		/* Format command to execute the object */
+		/* Format the command to execute the object */
 		cmd = g_strdup_printf(
 		    "%s &",
 		    path
@@ -552,7 +564,7 @@ a specific MIME Type, try File->Open With.",
 		gchar *parent, *cmd;
 		GList *paths_list = NULL;
 
-		/* Record previous working dir */
+		/* Record the previous working dir */
 		gchar *pwd = EDVGetCWD();
 
 		/* Set new working dir as the parent of the specified
@@ -1195,7 +1207,7 @@ Help->MIME Types...",
 	    gchar *parent, *cmd;
 	    GList *paths_list = NULL;
 
-	    /* Record previous working dir */
+	    /* Record the previous working dir */
 	    gchar *pwd = EDVGetCWD();  
 
 	    /* Set new working dir as the parent of the specified
@@ -1478,7 +1490,7 @@ Help->MIME Types...",
 	    gint pid;
 	    gchar *parent, *cmd;
 
-	    /* Record previous working dir */
+	    /* Record the previous working dir */
 	    gchar *pwd = EDVGetCWD();
 
 	    /* Set new working dir as the parent of the specified
