@@ -569,6 +569,7 @@ gchar *EDVTmpName(const gchar *dir)
  */
 gchar *EDVWhich(const gchar *name)
 {
+	struct stat stat_buf;
 	gint i;
 	const gchar *path_list;
 	gchar *s, *matched_path, **pathv;
@@ -601,10 +602,19 @@ gchar *EDVWhich(const gchar *name)
 	    if(s == NULL)
 		continue;
 
-	    if(!access((const char *)s, X_OK))
+	    if(!stat((const char *)s, &stat_buf))
 	    {
-		matched_path = s;
-		break;
+#if defined(S_IXUSR) && defined(S_IXGRP) && defined(S_IXOTH)
+		const mode_t m = stat_buf.st_mode;
+		if((m & S_IXUSR) ||
+                   (m & S_IXGRP) ||
+		   (m & S_IXOTH)
+		)
+		{
+		    matched_path = s;
+                    break;
+		}
+#endif
 	    }
 
 	    g_free(s);
