@@ -528,7 +528,8 @@ void EDVResizePixmap(
 	    GUIImageBufferResize(
 		4,
 		sdata, sw, sh, sbpl,
-		tdata, width, height, tbpl
+		tdata, width, height, tbpl,
+		NULL, NULL
 	    );
 
 	    g_free(sdata);
@@ -2752,9 +2753,9 @@ void EDVCenterWindowToWindowOffset(
 void EDVEntrySetDND(edv_core_struct *core, GtkWidget *w)
 {
 	const GtkTargetEntry dnd_tar_types[] = {
-{"text/plain",			0,	EDV_DND_TYPE_INFO_TEXT_PLAIN},
-{"text/uri-list",		0,	EDV_DND_TYPE_INFO_TEXT_URI_LIST},
-{"STRING",			0,	EDV_DND_TYPE_INFO_STRING}
+{"text/plain",			0,	EDV_DND_INFO_TEXT_PLAIN},
+{"text/uri-list",		0,	EDV_DND_INFO_TEXT_URI_LIST},
+{"STRING",			0,	EDV_DND_INFO_STRING}
 	};
 
 	if((core == NULL) || (w == NULL))
@@ -3154,11 +3155,9 @@ void EDVCopyDiskObjectsToDDEPath(
 	gchar *buf = NULL;
 	edv_object_struct *obj;
 
-
 	if((core == NULL) || (list == NULL) || (total <= 0))
 	    return;
 
-
 	for(i = 0; i < total; i++)
 	{
 	    obj = list[i];
