@@ -43,6 +43,10 @@ struct _edv_core_struct {
         gchar			*cfg_file;
 	cfg_item_struct		*cfg_list;
 
+	/* Data Types */
+	GdkAtom			data_type_recycled_object_atom,
+				data_type_archive_object_atom;
+
 	/* Pixmaps List (list of edv_pixmaps) */
 	GList			*pixmap_list;
 
