@@ -12,7 +12,7 @@
 
 #include "../guiutils.h"
 #include "../cdialog.h"
-#include "../edvtypes.h"
+#include "../edv_types.h"
 
 #include "fsckmanager.h"
 #include "fsckcb.h"
