@@ -1,8 +1,13 @@
 #ifdef HAVE_LIBGIF
-/* This version of the gif module is taken from IV, please update the
- * IV version and then copy it to here instead of updating this
- * one
+/* This version of the gif module is taken (coppied) from IV's
+ * imgiogif.c, please update the IV version and then copy it to here
+ * instead of updating this one
+ *
+ * The imgio_last_load_error and imgio_last_write_error need to be
+ * declared as static const char instead of extern const char.
  */
+
+#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <sys/types.h>
@@ -10,31 +15,18 @@
 #include <gif_lib.h>
 
 #include "rgba_to_cidx.h"
-#include "gif.h"
+#include "imgio.h"
 
 
 /* Last error message pointer */
-const char *imgio_last_load_error;
-const char *imgio_last_write_error;
+static const char	*imgio_last_load_error,
+			*imgio_last_write_error;
 
 
-/*
- *	RGBAToCIdx Callback Data:
- */
-typedef struct {
-	int		(*progress_cb)(
-		void *,		/* Data */
-		int, int,	/* Progress current & end values */
-		int, int,	/* Width & height */
-		int, int,	/* Bytes per line & bytes per pixel */
-		u_int8_t *	/* RGBA data */
-	);
-	void		*data;
-	u_int8_t	*rgba;
-	int		width, height,
-			bpp, bpl;
-	int		*user_aborted;
-} RGBAToCIdxData;
+typedef struct _ImgGIFReadData		ImgGIFReadData;
+#define IMG_GIF_READ_DATA(p)		((ImgGIFReadData *)(p))
+typedef struct _RGBAToCIdxData		RGBAToCIdxData;
+#define RGBA_TO_CIDX_DATA(p)		((RGBAToCIdxData *)(p))
 
 
 /* GIF Library Version */
@@ -43,6 +35,7 @@ void ImgGIFVersion(int *major, int *minor, int *release);
 mode_t ImgGIFGetFileMode(const char *filename);
 
 /* GIF Reading */
+static int ImgGIFReadCB(GifFileType *ft, GifByteType *buf, int buf_len);
 int ImgGIFReadRGBA(
 	const char *filename,
 	int *width_rtn, int *height_rtn, int *bpp_rtn, int *bpl_rtn,
@@ -69,13 +62,13 @@ int ImgGIFReadRGBA(
 /* GIF Dithering */
 static int ImgGIFRGBAToCIdxCB(int i, int m, void *data);
 static int ImgGIFDitherRGBA(
+	const int frame_num, const int nframes,
 	u_int8_t *rgba,
-	int width, int height, int bpl,
+	const int width, const int height, const int bpl,
 	const u_int8_t *bg_color, int *bg_color_num,
 	int *trans_color_num,
 	ColorMapObject **colormap_rtn,
-	GifByteType **data_rtn,
-	void *client_data,
+	GifByteType **data_rtn, int *data_bpl_rtn,
 	int (*progress_cb)(
 		void *,		/* Client data */
 		int, int,	/* Progress current & end values */
@@ -83,20 +76,20 @@ static int ImgGIFDitherRGBA(
 		int, int,	/* Bytes per line & bytes per pixel */
 		u_int8_t *	/* RGBA data */
 	),
+	void *progress_data,
 	int *user_aborted
 );
 /* GIF Writing */
 static int ImgWriteGIFFileRGBAToColor(
 	const char *filename,
-	int width, int height,
-	int bpl, int bpp,	/* bpp must be 4 */
+	const int width, const int height,
+	const int bpl, const int bpp,
 	u_int8_t **rgba, unsigned long *delay_list,
-	int nframes,
+	const int nframes,
 	const u_int8_t *bg_color,	/* 4 bytes in RGBA format */
 	const char *comments,
-	int interlaced,		/* 0 or 1 */
-	int transparency,	/* 0 or 1 */
-	void *client_data,
+	const int interlaced,	/* 0 or 1 */
+	const int transparency,	/* 0 or 1 */
 	int (*progress_cb)(
 		void *,		/* Client data */
 		int, int,	/* Progress current & end values */
@@ -104,19 +97,19 @@ static int ImgWriteGIFFileRGBAToColor(
 		int, int,	/* Bytes per line & bytes per pixel */
 		u_int8_t *	/* RGBA data */
 	),
+	void *progress_data,
 	int *user_aborted
 );
 static int ImgWriteGIFFileRGBAToGreyscale(
 	const char *filename,
-	int width, int height,
-	int bpl, int bpp,	/* bpp must be 4 */
+	const int width, const int height,
+	const int bpl, const int bpp,
 	u_int8_t **rgba, unsigned long *delay_list,
-	int nframes,
+	const int nframes,
 	const u_int8_t *bg_color,	/* 4 bytes in RGBA format */
 	const char *comments,
-	int interlaced,		/* 0 or 1 */
-	int transparency,	/* 0 or 1 */
-	void *client_data,
+	const int interlaced,	/* 0 or 1 */
+	const int transparency,	/* 0 or 1 */
 	int (*progress_cb)(
 		void *,		/* Client data */
 		int, int,	/* Progress current & end values */
@@ -124,19 +117,19 @@ static int ImgWriteGIFFileRGBAToGreyscale(
 		int, int,	/* Bytes per line & bytes per pixel */
 		u_int8_t *	/* RGBA data */
 	),
+	void *progress_data,
 	int *user_aborted
 );
 static int ImgWriteGIFFileRGBAToBW(
 	const char *filename,
-	int width, int height,
-	int bpl, int bpp,	/* bpp must be 4 */
+	const int width, const int height,
+	const int bpl, const int bpp,
 	u_int8_t **rgba, unsigned long *delay_list,
-	int nframes,
+	const int nframes,
 	const u_int8_t *bg_color,	/* 4 bytes in RGBA format */
 	const char *comments,
-	int interlaced,		/* 0 or 1 */
-	int transparency,	/* 0 or 1 */
-	void *client_data,
+	const int interlaced,	/* 0 or 1 */
+	const int transparency,	/* 0 or 1 */
 	int (*progress_cb)(
 		void *,		/* Client data */
 		int, int,	/* Progress current & end values */
@@ -144,6 +137,7 @@ static int ImgWriteGIFFileRGBAToBW(
 		int, int,	/* Bytes per line & bytes per pixel */
 		u_int8_t *	/* RGBA data */
 	),
+	void *progress_data,
 	int *user_aborted
 );
 int ImgWriteGIFFileRGBA(
@@ -170,6 +164,50 @@ int ImgWriteGIFFileRGBA(
 );
 
 
+/*
+ *	GIF Read Callback Data:
+ */
+struct _ImgGIFReadData {
+	FILE		*fp;
+	struct stat	stat_buf;
+	int		width, height,
+			bpp, bpl;
+	u_int8_t	*rgba;
+	int		(*progress_cb)(
+		void *,		/* Client data */
+		int, int,	/* Progress current & end values */
+		int, int,	/* Width & height */
+		int, int,	/* Bytes per line & bytes per pixel */
+		u_int8_t *	/* RGBA data */
+	);
+	void		*progress_data;
+	int		*user_aborted;
+};
+
+/*
+ *	RGBAToCIdx Callback Data:
+ */
+struct _RGBAToCIdxData {
+
+	int		(*progress_cb)(
+		void *,		/* Data */
+		int, int,	/* Progress current & end values */
+		int, int,	/* Width & height */
+		int, int,	/* Bytes per line & bytes per pixel */
+		u_int8_t *	/* RGBA data */
+	);
+	void		*data;
+	int		frame_num,
+			nframes;
+	u_int8_t	*rgba;
+	int		width,
+			height,
+			bpp,
+			bpl;
+	int		*user_aborted;
+};
+
+
 #define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
 #define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
 #define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
@@ -248,6 +286,52 @@ mode_t ImgGIFGetFileMode(const char *filename)
 }
 
 
+/*
+ *	GIF read callback.
+ */
+static int ImgGIFReadCB(GifFileType *ft, GifByteType *buf, int buf_len)
+{
+	int i, bytes_read, total_bytes_read, read_len;
+	ImgGIFReadData *d = IMG_GIF_READ_DATA(ft->UserData);
+	if((d == NULL) || (buf == NULL) || (buf_len <= 0))
+	    return(0);
+	if(d->fp == NULL)
+	    return(0);
+
+	total_bytes_read = 0;
+	read_len = MAX((int)d->stat_buf.st_blksize, 1);
+	i = 0;
+	while(i < buf_len)
+	{
+	    bytes_read = fread(
+		buf + i,
+		sizeof(GifByteType),
+		MIN((buf_len - i), read_len),
+		d->fp
+	    );
+	    if(bytes_read <= 0)
+		break;
+
+	    total_bytes_read += bytes_read;
+
+	    if(d->progress_cb != NULL)
+	    {
+		if(!d->progress_cb(
+		    d->progress_data,
+		    (int)ftell(d->fp), (int)d->stat_buf.st_size,
+		    d->width, d->height,
+		    d->bpl, d->bpp,
+		    d->rgba
+		))
+		    *d->user_aborted = 1;
+	    }
+
+	    i += bytes_read;
+	}
+
+	return(total_bytes_read);
+}
+
 /*
  *	Reads the GIF file.
  *
@@ -292,6 +376,7 @@ int ImgGIFReadRGBA(
 	GifFileType *ft;
 	GifRowType *scr_buf;		/* Main GIF screen buffer */
 	GifRecordType rt;
+	ImgGIFReadData *read_data;
 
 	/* Reset last load error */
 	imgio_last_load_error = NULL;
@@ -303,10 +388,30 @@ int ImgGIFReadRGBA(
 	    return(-4);
 	}
 
-	/* Open GIF file */
-	ft = DGifOpenFileName(filename);
+	/* Allocate the GIF read callback data */
+	read_data = IMG_GIF_READ_DATA(calloc(1, sizeof(ImgGIFReadData)));
+	if(read_data == NULL)
+	{
+	    imgio_last_load_error = "Memory allocation error";
+	    return(-3);
+	}
+	read_data->fp = fopen(filename, "rb");
+	if(read_data->fp == NULL)
+	{
+	    free(read_data);
+	    imgio_last_load_error = "Unable to open the file for reading";
+	    return(-1);
+	}
+	fstat(fileno(read_data->fp), &read_data->stat_buf);
+	read_data->progress_cb = progress_cb;
+	read_data->progress_data = client_data;
+	read_data->user_aborted = user_aborted;
+
+	ft = DGifOpen(read_data, ImgGIFReadCB);
 	if(ft == NULL)
 	{
+	    fclose(read_data->fp);
+	    free(read_data);
 	    imgio_last_load_error = "Unable to open the file for reading";
 	    return(-1);
 	}
@@ -316,14 +421,11 @@ int ImgGIFReadRGBA(
 	scr_height = ft->SHeight;
 	bg_color_num = ft->SBackGroundColor;
 
-#if 0
-printf(
- "Total Colors: %i  BG Color: #%i  Res: %i\n",
- ft->SColorMap->ColorCount,
- ft->SBackGroundColor,
- ft->SColorResolution
-);
-#endif
+	read_data->width = scr_width;
+	read_data->height = scr_height;
+	read_data->bpp = 4;
+	read_data->bpl = read_data->width * read_data->bpp;
+	read_data->rgba = NULL;
 
 	/* Get the GIF background color */
 	if((ft->SColorMap != NULL) && (bg_color != NULL))
@@ -345,6 +447,8 @@ printf(
 	if(scr_buf == NULL)
 	{
 	    DGifCloseFile(ft);
+	    fclose(read_data->fp);
+	    free(read_data);
 	    imgio_last_load_error = "Memory allocation error";
 	    return(-3);
 	}
@@ -375,12 +479,15 @@ printf(
 	 */
 	do
 	{
-	    if(*user_aborted)
+	    if(*read_data->user_aborted)
 		break;
 
 	    if(DGifGetRecordType(ft, &rt) == GIF_ERROR)
 		break;
 
+	    if(*read_data->user_aborted)
+		break;
+
 	    switch(rt)
 	    {
 	      case UNDEFINED_RECORD_TYPE:
@@ -392,8 +499,8 @@ printf(
 	      case IMAGE_DESC_RECORD_TYPE:
 		if(DGifGetImageDesc(ft) == GIF_OK)
 		{
-		    const int	rgba_bpp = 4,
-				rgba_bpl = scr_width * rgba_bpp,
+		    const int	rgba_bpp = read_data->bpp,
+				rgba_bpl = read_data->bpl,
 				frame_num = *nframes_rtn,
 				prev_frame_num = frame_num - 1;
 		    GifImageDesc *img = &ft->Image;
@@ -410,24 +517,25 @@ printf(
 		    const ColorMapObject *colormap = (img->ColorMap != NULL) ?
 			img->ColorMap : ft->SColorMap;
 
+		    if(*read_data->user_aborted)
+			break;
+
 		    /* No colormap defined by local image or system? */
 		    if((colormap != NULL) ? (colormap->ColorCount <= 0) : TRUE)
 			break;
 
 		    /* Allocate the RGBA image data */
-		    rgba = (u_int8_t *)malloc(rgba_bpl * scr_height);
+		    read_data->rgba = rgba = (u_int8_t *)malloc(
+			rgba_bpl * scr_height
+		    );
 		    if(rgba == NULL)
 			break;
 
-		    /* Load this GIF image to the GIF screen buffer */
+		    /* Open this GIF image to the GIF screen buffer */
 
 		    /* Interlaced? */
 		    if(img->Interlace)
 		    {
-			const int	po = 0,
-					pm = 2 * height;
-			int lines_loaded = 0;
-
 			/* Interlace needs 4 passes on the image */
 			for(i = 0; i < 4; i++)
 			{
@@ -443,32 +551,14 @@ printf(
 				) == GIF_ERROR)
 				    break;
 
-				lines_loaded++;
-
-				/* Report progress */
-				if((progress_cb != NULL) &&
-				   ((lines_loaded % 5) == 0)
-				)
-				{
-				    if(!progress_cb(
-					client_data,
-					po + lines_loaded, pm,
-					scr_width, scr_height,
-					rgba_bpl, rgba_bpp,
-					rgba
-				    ))
-				    {
-					*user_aborted = 1;
-					break;
-				    }
-				}
+				/* Check for user abort */
+				if(*read_data->user_aborted)
+				    break;
 			    }
 			}
 		    }
 		    else
 		    {
-			const int	po = 0,
-					pm = 2 * height;
 			/* Read each line sequentially */
 			for(i = 0; i < height; i++)
 			{
@@ -479,26 +569,12 @@ printf(
 			    ) == GIF_ERROR)
 				break;
 
-			    /* Report progress */
-			    if((progress_cb != NULL) &&
-			       ((i % 5) == 0)
-			    )
-			    {
-				if(!progress_cb(
-				    client_data,
-				    po + i, pm,
-				    scr_width, scr_height,
-				    rgba_bpl, rgba_bpp,
-				    rgba
-				))
-				{ 
-				    *user_aborted = 1;
-				    break;
-				}
-			    }
+			    /* Check for user abort */
+			    if(*read_data->user_aborted)
+				break;
 			}
 		    }
-		    if(*user_aborted)
+		    if(*read_data->user_aborted)
 		    {
 			free(rgba);
 			break;
@@ -563,27 +639,6 @@ printf(
 				*rgba_ptr++ = 0x00;
 			    }
 			}
-
-			/* Report progress */
-			if((progress_cb != NULL) && ((y % 5) == 0))
-			{
-			    if(!progress_cb(
-				client_data,
-				scr_height + y, 2 * scr_height,
-				scr_width, scr_height,
-				rgba_bpl, rgba_bpp,
-				rgba
-			    ))
-			    {
-				*user_aborted = 1;
-				break;
-			    }
-			}
-		    }
-		    if(*user_aborted)
-		    {
-			free(rgba);
-			break;
 		    }
 
 		    /* Append the RGBA image data to the list */
@@ -603,10 +658,10 @@ printf(
 		     */
 		    if(disposal_method == 2)
 		    {
-			/* Clear first line */
+			/* Clear the first line */
 			for(i = 0; i < scr_width; i++)
 			    scr_buf[0][i] = bg_color_num;
-			/* Copy first line to subsequent lines */
+			/* Copy the first line to the subsequent lines */
 			for(i = 1; i < scr_height; i++)
 			    memcpy(scr_buf[i], scr_buf[0], scr_bpl);
 		    }
@@ -619,11 +674,11 @@ printf(
 		    int code;
 		    GifByteType *ext, ext_len;
 
-		    /* Get first extension */
+		    /* Get the first extension */
 		    if(DGifGetExtension(ft, &code, &ext) == GIF_OK)
 		    {
-			/* Iterate through extensions */
-			while(ext != NULL)
+			/* Iterate through the extensions */
+			while((ext != NULL) && !(*read_data->user_aborted))
 			{
 			    /* Get this extension's length */
 			    ext_len = ext[0];
@@ -700,7 +755,7 @@ printf(
 				break;
 			    }
 
-			    /* Get next extension */
+			    /* Get the next extension */
 			    if(DGifGetExtensionNext(ft, &ext) == GIF_ERROR)
 				break;
 			}
@@ -708,22 +763,24 @@ printf(
 		}
 		break;
 
-	    case TERMINATE_RECORD_TYPE:
+	      case TERMINATE_RECORD_TYPE:
 		break;
 	    }
 	}
 	while(rt != TERMINATE_RECORD_TYPE);
 
 
-	/* Close the GIF file */
+	/* Close the GIF file and delete the read data */
 	DGifCloseFile(ft);
+	fclose(read_data->fp);
+	free(read_data);
 
 	/* Delete the GIF screen buffer */
 	for(i = 0; i < scr_height; i++)
 	    free(scr_buf[i]);
 	free(scr_buf);
 
-	/* Update returns */
+	/* Update the returns */
 	if(width_rtn != NULL)
 	    *width_rtn = scr_width;
 	if(height_rtn != NULL)
@@ -769,7 +826,8 @@ static int ImgGIFRGBAToCIdxCB(int i, int m, void *data)
 	{
 	    if(!d->progress_cb(
 		d->data,
-		i / 2, m,
+		(d->frame_num * m) + (i / 2),
+		(d->nframes * m),
 		d->width, d->height,
 		d->bpl, d->bpp,
 		d->rgba
@@ -796,13 +854,13 @@ static int ImgGIFRGBAToCIdxCB(int i, int m, void *data)
  *	Inputs assumed valid except as noted above.
  */
 static int ImgGIFDitherRGBA(
+	const int frame_num, const int nframes,
 	u_int8_t *rgba,
-	int width, int height, int bpl,
+	const int width, const int height, const int bpl,
 	const u_int8_t *bg_color, int *bg_color_num,
 	int *trans_color_num,
 	ColorMapObject **colormap_rtn,
-	GifByteType **data_rtn,
-	void *client_data,
+	GifByteType **data_rtn, int *data_bpl_rtn,
 	int (*progress_cb)(
 		void *,		/* Client data */
 		int, int,	/* Progress current & end values */
@@ -810,11 +868,12 @@ static int ImgGIFDitherRGBA(
 		int, int,	/* Bytes per line & bytes per pixel */
 		u_int8_t *	/* RGBA data */
 	),
+	void *progress_data,
 	int *user_aborted
 )
 {
 	const int bpp = 4;
-	int		i, n, ncolors,
+	int		i, n, data_bpl, ncolors,
 			max_colors = 256;
 	u_int8_t *cidx;
 	GifColorType *gif_c;
@@ -832,7 +891,9 @@ static int ImgGIFDitherRGBA(
 	/* Allocate the RGBAToCIdx() callback data */
 	d = (RGBAToCIdxData *)calloc(1, sizeof(RGBAToCIdxData));
 	d->progress_cb = progress_cb;
-	d->data = client_data;
+	d->data = progress_data;
+	d->frame_num = frame_num;
+	d->nframes = nframes;
 	d->width = width;
 	d->height = height;
 	d->bpp = bpp;
@@ -865,6 +926,7 @@ static int ImgGIFDitherRGBA(
 
 	/* Get the generated color index image as the GIF image */
 	data = (GifByteType *)cidx;
+	data_bpl = width * sizeof(GifByteType);
 	if(data == NULL)
 	{
 	    free(colors_list);
@@ -882,10 +944,10 @@ static int ImgGIFDitherRGBA(
 	    return(-1);
 	}
 
-	/* Append background color? */
+	/* Append the background color? */
 	if(bg_color != NULL)
 	{
-	    i = ncolors;
+	    const int i = ncolors;
 	    ncolors = i + 1;
 	    colors_list = (ColormapColor *)realloc(
 		colors_list,
@@ -916,7 +978,7 @@ static int ImgGIFDitherRGBA(
 	/* Append transparent color? */
 	else if(trans_color_num != NULL)
 	{
-	    i = ncolors;
+	    const int i = ncolors;
 	    ncolors = i + 1;
 	    colors_list = (ColormapColor *)realloc(
 		colors_list,
@@ -934,7 +996,9 @@ static int ImgGIFDitherRGBA(
 	    *trans_color_num = i;
 	}
 
-	/* Need to apply transparency to the color index image data? */
+	/* Need to apply the transparency to the color index image
+	 * data?
+	 */
 	if(trans_color_num != NULL)
 	{
 	    const int	cidx_bpp = sizeof(GifByteType),
@@ -942,10 +1006,9 @@ static int ImgGIFDitherRGBA(
 	    const GifByteType v = (GifByteType)(*trans_color_num);
 	    int y;
 	    const u_int8_t alpha_threshold = 0x80;
-	    const u_int8_t *rgba_ptr, *rgba_end;
+	    const u_int8_t *rgba_ptr;
 	    GifByteType *cidx_ptr, *cidx_end;
 
-
 	    /* Scan the RGBA image data, set all values on the color
 	     * index image to the transparent color number v that
 	     * correspond to a transparent pixel on the RGBA image
@@ -954,12 +1017,9 @@ static int ImgGIFDitherRGBA(
 	    for(y = 0; y < height; y++)
 	    {
 		rgba_ptr = rgba + (y * bpl);
-		rgba_end = rgba_ptr + (width * bpp);
 		cidx_ptr = data + (y * cidx_bpl);
 	        cidx_end = cidx_ptr + (width * cidx_bpp);
-	        while((rgba_ptr < rgba_end) &&
-		      (cidx_ptr < cidx_end)
-		)
+	        while(cidx_ptr < cidx_end)
 	        {
 		    /* Transparent? */
 		    if(rgba_ptr[3] < alpha_threshold)
@@ -998,6 +1058,7 @@ static int ImgGIFDitherRGBA(
 	free(colors_list);
 
 	*data_rtn = data;
+	*data_bpl_rtn = data_bpl;
 	*colormap_rtn = colormap;
 
 	return(0);
@@ -1009,15 +1070,14 @@ static int ImgGIFDitherRGBA(
  */
 static int ImgWriteGIFFileRGBAToColor(
 	const char *filename,
-	int width, int height,
-	int bpl, int bpp,	/* bpp must be 4 */
+	const int width, const int height,
+	const int bpl, const int bpp,
 	u_int8_t **rgba, unsigned long *delay_list,
-	int nframes,
+	const int nframes,
 	const u_int8_t *bg_color,	/* 4 bytes in RGBA format */
 	const char *comments,
-	int interlaced,		/* 0 or 1 */
-	int transparency,	/* 0 or 1 */
-	void *client_data,
+	const int interlaced,	/* 0 or 1 */
+	const int transparency,	/* 0 or 1 */
 	int (*progress_cb)(
 		void *,		/* Client data */
 		int, int,	/* Progress current & end values */
@@ -1025,10 +1085,11 @@ static int ImgWriteGIFFileRGBAToColor(
 		int, int,	/* Bytes per line & bytes per pixel */
 		u_int8_t *	/* RGBA data */
 	),
+	void *progress_data,
 	int *user_aborted
 )
 {
-	int	status, frame_num, disposal_method,
+	int	status, frame_num, cidx_bpl, disposal_method,
 		color_resolution = 8,
 		bg_color_num = 0,
 		trans_color_num = -1;
@@ -1065,16 +1126,15 @@ static int ImgWriteGIFFileRGBAToColor(
 	     * colormap and the GIF color index image data
 	     */
 	    status = ImgGIFDitherRGBA(
+		frame_num, nframes,
 		rgba_cur, width, height, bpl,
 		bg_color, &bg_color_num,
 		&trans_color_num,
 		&colormap,
-		&cidx,
-		client_data,
-		progress_cb,
-		user_aborted
+		&cidx, &cidx_bpl,
+		progress_cb, progress_data, user_aborted
 	    );
-	    if(status || (colormap == NULL) || (cidx == NULL))
+	    if((status != 0) || (colormap == NULL) || (cidx == NULL))
 	    {
 		if(colormap != NULL)
 		    FreeMapObject(colormap);
@@ -1108,7 +1168,7 @@ static int ImgWriteGIFFileRGBAToColor(
 	    else
 		disposal_method = 1;	/* Do not clear */
 
-	    /* Write the graphic control */
+	    /* Write the graphic control as needed */
 	    if(transparency || user_input ||
 	       (disposal_method != 0) || (delay > 0l)
 	    )
@@ -1141,7 +1201,7 @@ static int ImgWriteGIFFileRGBAToColor(
 		0, 0,		/* Top & left */
 		width, height,	/* Width & height */
 		interlaced,	/* Interlace */
-		/* Specify local colormap only if multiple frames */
+		/* Specify the local colormap only if multiple frames */
 		(nframes > 1) ? colormap : NULL
 	    );
 
@@ -1165,8 +1225,8 @@ static int ImgWriteGIFFileRGBAToColor(
 		    {
 			EGifPutLine(
 			    ft,
-			    (GifPixelType *)(cidx + (y * width)),
-			    width
+			    (GifPixelType *)(cidx + (y * cidx_bpl)),
+			    cidx_bpl
 			);
 			lines_written++;
 
@@ -1174,8 +1234,9 @@ static int ImgWriteGIFFileRGBAToColor(
 			if((progress_cb != NULL) && ((lines_written % 5) == 0))
 			{
 			    if(!progress_cb(
-				client_data,
-				po + lines_written, pm,
+				progress_data,
+				(frame_num * pm) + (po + lines_written),
+				(nframes * pm),
 				width, height,
 				bpl, bpp,
 				rgba_cur
@@ -1197,7 +1258,7 @@ static int ImgWriteGIFFileRGBAToColor(
 		for(y = 0; y < height; y++)
 		{
 		    EGifPutLine(
-			ft, (GifPixelType *)cidx_ptr, width
+			ft, (GifPixelType *)cidx_ptr, cidx_bpl
 		    );
 		    cidx_ptr += width;
 
@@ -1205,8 +1266,9 @@ static int ImgWriteGIFFileRGBAToColor(
 		    if((progress_cb != NULL) && ((y % 5) == 0))
 		    {
 			if(!progress_cb(
-			    client_data,
-			    po + y, pm,
+			    progress_data,
+			    (frame_num * pm) + (po + y),
+			    (nframes * pm),
 			    width, height,
 			    bpl, bpp,
 			    rgba_cur
@@ -1253,15 +1315,14 @@ static int ImgWriteGIFFileRGBAToColor(
  */
 static int ImgWriteGIFFileRGBAToGreyscale(
 	const char *filename,
-	int width, int height,
-	int bpl, int bpp,	/* bpp must be 4 */
+	const int width, const int height,
+	const int bpl, const int bpp,
 	u_int8_t **rgba, unsigned long *delay_list,
-	int nframes,
+	const int nframes,
 	const u_int8_t *bg_color,	/* 4 bytes in RGBA format */
 	const char *comments,
-	int interlaced,		/* 0 or 1 */
-	int transparency,	/* 0 or 1 */
-	void *client_data,
+	const int interlaced,	/* 0 or 1 */
+	const int transparency,	/* 0 or 1 */
 	int (*progress_cb)(
 		void *,		/* Client data */
 		int, int,	/* Progress current & end values */
@@ -1269,10 +1330,11 @@ static int ImgWriteGIFFileRGBAToGreyscale(
 		int, int,	/* Bytes per line & bytes per pixel */
 		u_int8_t *	/* RGBA data */
 	),
+	void *progress_data,
 	int *user_aborted
 )
 {
-	int	frame_num, disposal_method,
+	int	frame_num, cidx_bpl, disposal_method,
 		color_resolution = 8,
 		colormap_ncolors_set = 256,	/* Must be 256 or else fails */
 		bg_color_num = 0,
@@ -1292,24 +1354,43 @@ static int ImgWriteGIFFileRGBAToGreyscale(
 	colormap->Colors = (GifColorType *)calloc(
 	    colormap->ColorCount, sizeof(GifColorType)
 	);
-	/* Generate greyscale colors */
+	/* Generate the greyscale colors */
 	if(colormap->Colors != NULL)
 	{
+	    GifByteType v_bg;
+
+	    /* Calculate the greyscale background color */
+	    if(bg_color != NULL)
+		v_bg = (GifByteType)(
+		    ((int)bg_color[0] + (int)bg_color[1] +
+		    (int)bg_color[2]
+		) / 3);
+	    else
+		v_bg = 0x00;
+
 	    if(transparency)
 	    {
 		/* Generate 255 colors from black to white, leaving
 		 * color 255 for the transparent pixel
 		 */
-		int i, m = colormap->ColorCount - 1, n = MAX(m - 1, 1);
+		const int	m = colormap->ColorCount - 1,
+				n = MAX(m - 1, 1);
+		int i;
 		GifColorType *c;
 		for(i = 0; i < m; i++)
 		{
 		    c = &colormap->Colors[i];
 		    c->Red = c->Green = c->Blue =
 			(GifByteType)(i * 0xff / n);
+
+		    /* If this color matches the background color then
+		     * set this color as the background color
+		     */
+		    if(c->Red == v_bg)
+			bg_color_num = i;
 		}
 
-		/* Set transparent color */
+		/* Set the transparent color */
 		trans_color_num = m;
 		c = &colormap->Colors[trans_color_num];
 		c->Red = c->Green = c->Blue = 0xff;
@@ -1324,14 +1405,19 @@ static int ImgWriteGIFFileRGBAToGreyscale(
 		    c = &colormap->Colors[i];
 		    c->Red = c->Green = c->Blue =
 			(GifByteType)(i * 0xff / n);
+
+		    /* If this color matches the background color then
+		     * set this color as the background color
+		     */
+		    if(c->Red == v_bg)
+			bg_color_num = i;
 		}
 	    }
 	}
 
 	/* Create the GIF color index image data */
-	cidx = (GifByteType *)malloc(
-	    width * height * sizeof(GifByteType)
-	);
+	cidx_bpl = width * sizeof(GifByteType);
+	cidx = (GifByteType *)malloc(cidx_bpl * height);
 	if(cidx == NULL)
 	{
 	    FreeMapObject(colormap);
@@ -1368,8 +1454,7 @@ static int ImgWriteGIFFileRGBAToGreyscale(
 	    if(transparency && (trans_color_num > -1))
 	    {
 		GifByteType	*cidx_ptr = cidx,
-				*cidx_end = cidx_ptr +
-				    (width * height);
+				*cidx_end = cidx_ptr + (cidx_bpl * height);
 		const u_int8_t *rgba_ptr = rgba_cur;
 		while(cidx_ptr < cidx_end)
 	        {
@@ -1387,8 +1472,7 @@ static int ImgWriteGIFFileRGBAToGreyscale(
 	    else
 	    {
 		GifByteType	*cidx_ptr = cidx,
-				*cidx_end = cidx_ptr +
-				    (width * height);
+				*cidx_end = cidx_ptr + (cidx_bpl * height);
 		const u_int8_t *rgba_ptr = rgba_cur;
 		while(cidx_ptr < cidx_end)
 		{
@@ -1472,8 +1556,8 @@ static int ImgWriteGIFFileRGBAToGreyscale(
 		    {
 			EGifPutLine( 
 			    ft,
-			    (GifPixelType *)(cidx + (y * width)),
-			    width
+			    (GifPixelType *)(cidx + (y * cidx_bpl)),
+			    cidx_bpl
 			);
 			lines_written++;
 
@@ -1481,8 +1565,9 @@ static int ImgWriteGIFFileRGBAToGreyscale(
 			if((progress_cb != NULL) && ((lines_written % 5) == 0))
 			{
 			    if(!progress_cb(
-			        client_data,
-				po + lines_written, pm,
+			        progress_data,
+				(frame_num * pm) + (po + lines_written),
+				(nframes * pm),
 				width, height,
 				bpl, bpp,
 				rgba_cur
@@ -1503,15 +1588,16 @@ static int ImgWriteGIFFileRGBAToGreyscale(
 		GifByteType *cidx_ptr = cidx;
 		for(y = 0; y < height; y++)
 		{
-		    EGifPutLine(ft, (GifPixelType *)cidx_ptr, width);
+		    EGifPutLine(ft, (GifPixelType *)cidx_ptr, cidx_bpl);
 		    cidx_ptr += width;
 
 		    /* Report progress */
 		    if((progress_cb != NULL) && ((y % 5) == 0))
 		    {
 			if(!progress_cb(
-			    client_data,
-			    po + y, pm,
+			    progress_data,
+			    (frame_num * pm) + (po + y),
+			    (nframes * pm),
 			    width, height,
 			    bpl, bpp,
 			    rgba_cur
@@ -1558,15 +1644,14 @@ static int ImgWriteGIFFileRGBAToGreyscale(
  */
 static int ImgWriteGIFFileRGBAToBW(
 	const char *filename,
-	int width, int height,
-	int bpl, int bpp,	/* bpp must be 4 */
+	const int width, const int height,
+	const int bpl, const int bpp,
 	u_int8_t **rgba, unsigned long *delay_list,
-	int nframes,
+	const int nframes,
 	const u_int8_t *bg_color,	/* 4 bytes in RGBA format */
 	const char *comments,
-	int interlaced,		/* 0 or 1 */
-	int transparency,	/* 0 or 1 */
-	void *client_data,
+	const int interlaced,	/* 0 or 1 */
+	const int transparency,	/* 0 or 1 */
 	int (*progress_cb)(
 		void *,		/* Client data */
 		int, int,	/* Progress current & end values */
@@ -1574,10 +1659,11 @@ static int ImgWriteGIFFileRGBAToBW(
 		int, int,	/* Bytes per line & bytes per pixel */
 		u_int8_t *	/* RGBA data */
 	),
+	void *progress_data,
 	int *user_aborted
 )
 {
-	int	frame_num, disposal_method,
+	int	frame_num, cidx_bpl, disposal_method,
 		color_resolution = 8,
 		colormap_ncolors_set = 256,	/* Must be 256 or else fails */
 		bg_color_num = 0,
@@ -1600,10 +1686,26 @@ static int ImgWriteGIFFileRGBAToBW(
 	/* Generate black and white colors */
 	if(colormap->Colors != NULL)
 	{
+	    GifByteType v_bg;
+
+	    /* Calculate the black and white background color */
+	    if(bg_color != NULL)
+	    {
+		const GifByteType v = (GifByteType)((
+		    (int)bg_color[0] + (int)bg_color[1] +
+		    (int)bg_color[2]
+		) / 3);
+		v_bg = (v >= 0x80) ? 0xff : 0x00;
+	    }
+	    else
+	    {
+		v_bg = 0x00;
+	    }
+
 	    if(transparency)
 	    {
 		/* Generate 3 colors; black, white, and the rest
-		 * are black (including color 255 for the transparent
+		 * are black (including color 2 for the transparent
 		 * pixel)
 		 */
 
@@ -1611,6 +1713,8 @@ static int ImgWriteGIFFileRGBAToBW(
 		int i = 0, m = colormap->ColorCount;
 		GifColorType *c = &colormap->Colors[i];
 		c->Red = c->Green = c->Blue = (GifByteType)0x00;
+		if(c->Red == v_bg)
+		    bg_color_num = i;
 
 		/* Set color 1 to white */
 		i = 1;
@@ -1618,6 +1722,8 @@ static int ImgWriteGIFFileRGBAToBW(
 		{
 		    c = &colormap->Colors[i]; 
 		    c->Red = c->Green = c->Blue = (GifByteType)0xff;
+		    if(c->Red == v_bg)
+			bg_color_num = i;
 		}
 
 		/* Set color 2 (transparent) to black */
@@ -1660,9 +1766,8 @@ static int ImgWriteGIFFileRGBAToBW(
 	}
 
 	/* Create the GIF color index image data */
-	cidx = (GifByteType *)malloc(
-	    width * height * sizeof(GifByteType)
-	);
+	cidx_bpl = width * sizeof(GifByteType);
+	cidx = (GifByteType *)malloc(cidx_bpl * height);
 	if(cidx == NULL)
 	{
 	    FreeMapObject(colormap);
@@ -1804,8 +1909,8 @@ static int ImgWriteGIFFileRGBAToBW(
 		    {
 			EGifPutLine(
 			    ft,
-			    (GifPixelType *)(cidx + (y * width)),
-			    width                               
+			    (GifPixelType *)(cidx + (y * cidx_bpl)),
+			    cidx_bpl
 			);
 			lines_written++;
 
@@ -1813,8 +1918,9 @@ static int ImgWriteGIFFileRGBAToBW(
 			if((progress_cb != NULL) && ((lines_written % 5) == 0))
 			{
 			    if(!progress_cb(
-				client_data,
-				po + lines_written, pm,
+				progress_data,
+				(frame_num * pm) + (po + lines_written),
+				(nframes * pm),
 				width, height,
 				bpl, bpp,
 				rgba_cur
@@ -1835,15 +1941,16 @@ static int ImgWriteGIFFileRGBAToBW(
 		GifByteType *cidx_ptr = cidx;
 		for(y = 0; y < height; y++)
 		{
-		    EGifPutLine(ft, (GifPixelType *)cidx_ptr, width);
+		    EGifPutLine(ft, (GifPixelType *)cidx_ptr, cidx_bpl);
 		    cidx_ptr += width;
 
 		    /* Report progress */
 		    if((progress_cb != NULL) && ((y % 5) == 0))
 		    {
 			if(!progress_cb(
-			    client_data,
-			    po + y, pm,
+			    progress_data,
+			    (frame_num * pm) + (po + y),
+			    (nframes * pm),
 			    width, height,
 			    bpl, bpp,
 			    rgba_cur
@@ -1963,7 +2070,7 @@ int ImgWriteGIFFileRGBA(
 		comments,
 		interlaced,
 		transparency,
-		client_data, progress_cb, &user_aborted
+		progress_cb, client_data, &user_aborted
 	    );
 	    break;
 
@@ -1976,7 +2083,7 @@ int ImgWriteGIFFileRGBA(
 		comments,
 		interlaced,
 		transparency,
-		client_data, progress_cb, &user_aborted
+		progress_cb, client_data, &user_aborted
 	    );
 	    break;
 
@@ -1989,7 +2096,7 @@ int ImgWriteGIFFileRGBA(
 		comments,
 		interlaced,
 		transparency,
-		client_data, progress_cb, &user_aborted
+		progress_cb, client_data, &user_aborted
 	    );
 	    break;
 
