@@ -40,16 +40,49 @@
 #ifndef GDK_BUTTON5
 # define GDK_BUTTON5		5
 #endif
+#ifndef GDK_BUTTON6
+# define GDK_BUTTON6		6
+#endif
+#ifndef GDK_BUTTON7
+# define GDK_BUTTON7		7
+#endif
+#ifndef GDK_BUTTON8
+# define GDK_BUTTON8		8
+#endif
+#ifndef GDK_BUTTON9
+# define GDK_BUTTON9		9
+#endif
+#ifndef GDK_BUTTON10
+# define GDK_BUTTON10		10
+#endif
+#ifndef GDK_BUTTON11
+# define GDK_BUTTON11		11
+#endif
+#ifndef GDK_BUTTON12
+# define GDK_BUTTON12		12
+#endif
+#ifndef GDK_BUTTON13
+# define GDK_BUTTON13		13
+#endif
+#ifndef GDK_BUTTON14
+# define GDK_BUTTON14		14
+#endif
+#ifndef GDK_BUTTON15
+# define GDK_BUTTON15		15
+#endif
+#ifndef GDK_BUTTON16
+# define GDK_BUTTON16		16
+#endif
 
 
 /*
  *	Geometry Flags:
  */
 typedef enum {
-	GDK_GEOMETRY_X				= (1 << 0),
-	GDK_GEOMETRY_Y				= (1 << 1),
-	GDK_GEOMETRY_WIDTH			= (1 << 2),
-	GDK_GEOMETRY_HEIGHT			= (1 << 3)
+	GDK_GEOMETRY_X			= (1 << 0),
+	GDK_GEOMETRY_Y			= (1 << 1),
+	GDK_GEOMETRY_WIDTH		= (1 << 2),
+	GDK_GEOMETRY_HEIGHT		= (1 << 3)
 } GdkGeometryFlags;
 
 /*
@@ -115,7 +148,7 @@ typedef enum {
  *	Colormap & Color Macros:
  */
 #define GDK_COLOR_SET_BYTE(_c_,_r_,_g_,_b_)		\
-{ if((_c_) != NULL) {                                   \
+{ if((_c_) != NULL) {					\
  (_c_)->red	= ((gushort)(_r_) << 8) |		\
 		  ((gushort)(_r_));			\
  (_c_)->green	= ((gushort)(_g_) << 8) |		\
@@ -131,8 +164,6 @@ typedef enum {
  (_c_)->blue	= (gushort)((gfloat)(_b_) * m);		\
 } }
 
-#define GDK_COLORMAP_UNREF(_cmap_)	\
-{ if((_cmap_) != NULL) gdk_colormap_unref(_cmap_); }
 #define GDK_COLORMAP_ALLOC_COLOR(_cmap_,_c_)	\
 { if(((_cmap_) != NULL) && ((_c_) != NULL))	\
  gdk_colormap_alloc_color((_cmap_), (_c_), TRUE, TRUE); \
@@ -163,6 +194,10 @@ typedef enum {
 { if((_p_) != NULL) gdk_font_ref(_p_); }
 #define GDK_FONT_UNREF(_p_)	\
 { if((_p_) != NULL) gdk_font_unref(_p_); }
+#define GDK_COLORMAP_REF(_p_)	\
+{ if((_p_) != NULL) gdk_colormap_ref(_p_); }
+#define GDK_COLORMAP_UNREF(_p_)	\
+{ if((_p_) != NULL) gdk_colormap_unref(_p_); }
 #define GDK_BITMAP_REF(_p_)	\
 { if((_p_) != NULL) gdk_bitmap_ref(_p_); }
 #define GDK_BITMAP_UNREF(_p_)	\
@@ -226,12 +261,16 @@ typedef enum {
 /*
  *      GtkAdjustment Macros:
  */
-#define GTK_ADJUSTMENT_GET_VALUE(_a_)   (((_a_) != NULL) ? \
+#define GTK_ADJUSTMENT_GET_VALUE(_a_)	(((_a_) != NULL) ? \
  ((GtkAdjustment *)(_a_))->value : 0.0f)
 
 /*
  *      GtkWidget Macros:
  */
+#define GTK_WIDGET_REF(_w_)			\
+{ if((_w_) != NULL) gtk_widget_ref(_w_); }
+#define GTK_WIDGET_UNREF(_w_)			\
+{ if((_w_) != NULL) gtk_widget_unref(_w_); }
 #define GTK_WIDGET_SET_SENSITIVE(_w_,_b_)	\
 { if((_w_) != NULL) gtk_widget_set_sensitive((_w_), (_b_)); }
 #define GTK_WIDGET_DESTROY(_w_)			\
@@ -276,15 +315,11 @@ typedef enum {
 #define GTK_ENTRY_GET_VALUEI(_w_)		\
  (((_w_) != NULL) ? atoi(gtk_entry_get_text(GTK_ENTRY(_w_))) : 0)
 #define GTK_ENTRY_GET_VALUEL(_w_)		\
- (((_w_) != NULL) ? atol(gtk_entry_get_text(GTK_ENTRY(_w_))) : 0.0f)
+ (((_w_) != NULL) ? atol(gtk_entry_get_text(GTK_ENTRY(_w_))) : 0l)
 #define GTK_ENTRY_GET_VALUEF(_w_)		\
  (((_w_) != NULL) ? atof(gtk_entry_get_text(GTK_ENTRY(_w_))) : 0.0f)
 
 
-/* Block/Unblock Input */
-extern void GUIBlockInput(GtkWidget *w, gboolean block);
-
-
 /* GtkRcStyle Utilities */
 #if (GTK_MAJOR_VERSION == 1)
 # define gtk_rc_style_copy	GUIRCStyleCopy
@@ -302,7 +337,7 @@ extern GdkGeometryFlags GUIParseGeometry(
 );
 #define gtk_clist_get_cell_geometry	GUICListGetCellGeometry
 extern gboolean GUICListGetCellGeometry(
-	GtkCList *clist, gint column, gint row,
+	GtkCList *clist, const gint column, const gint row,
 	gint *x, gint *y, gint *width, gint *height
 );
 #define gtk_ctree_get_node_row_index	GUICTreeNodeRow
@@ -310,7 +345,7 @@ extern gint GUICTreeNodeRow(GtkCTree *ctree, GtkCTreeNode *node);
 
 extern gint GUICTreeNodeDeltaRows(
 	GtkCTree *ctree,
-	GtkCTreeNode *start,    /* Use NULL for first/toplevel node */
+	GtkCTreeNode *start,	/* Use NULL for first/toplevel node */
 	GtkCTreeNode *end
 );
 #define gdk_window_get_root_position	GUIGetWindowRootPosition
@@ -325,7 +360,7 @@ extern void GUIGetPositionRoot(
 /* String Utilities */
 #define gdk_text_bounds		GUIGetTextBounds
 extern void GUIGetTextBounds(
-	GdkFont *font, const gchar *text, gint text_length,
+	GdkFont *font, const gchar *text, const gint text_length,
 	GdkTextBounds *bounds
 );
 #define gdk_string_bounds	GUIGetStringBounds
@@ -339,6 +374,11 @@ extern void GUIGetStringBounds(
 extern GdkGC *GDK_GC_NEW(void);
 
 
+/* Block/Unblock Input */
+extern void GUIBlockInput(GtkWidget *w, const gboolean block);
+extern gint GUIBlockInputGetLevel(void);
+
+
 /* GdkWindow utilities */
 #define gdk_window_get_ref_count	GUIWindowGetRefCount
 extern gint GUIWindowGetRefCount(GdkWindow *window);
@@ -352,6 +392,8 @@ extern void GUISetWMIconFile(GdkWindow *window, const gchar *filename);
 /* GtkWindow Utilities */
 #define gtk_window_apply_args GUIWindowApplyArgs
 extern void GUIWindowApplyArgs(GtkWindow *w, gint argc, gchar **argv);
+#define gtk_is_window_arg GUIIsWindowArg
+extern gboolean GUIIsWindowArg(const gchar *arg);
 
 
 /* GtkCTree Utilities */
@@ -377,7 +419,7 @@ extern GdkPixmap *GDK_PIXMAP_NEW_FROM_XPM_FILE(
 	GdkBitmap **mask_rtn, const gchar *filename
 );
 extern GtkWidget *gtk_pixmap_new_from_xpm_d(
-	GdkWindow *window, GdkColor *transparent_color,            
+	GdkWindow *window, GdkColor *transparent_color,
 	guint8 **data
 );
 extern GtkWidget *GUICreateMenuItemIcon(guint8 **icon_data);
@@ -460,28 +502,50 @@ extern GtkWidget *GUIPromptBar(
 
 
 /* Dynamic Data Exchange */
+extern void GUIDDESetDirect(
+	GtkWidget *w,
+	GdkAtom selection_atom,
+	const gulong t,
+	GdkAtom target_atom,
+	guint8 *data, const gint length
+);
+extern void GUIDDESet(
+        GtkWidget *w,
+        GdkAtom selection_atom,
+        const gulong t,
+        GdkAtom target_atom,
+        const guint8 *data, const gint length
+);
+extern guint8 *GUIDDEGet(
+        GtkWidget *w,
+        GdkAtom selection_atom,
+        const gulong t,
+        GdkAtom target_atom,
+        gint *length
+);
+extern void GUIDDEClear(GtkWidget *w);
 extern void GUIDDESetBinary(
-	GtkWidget *w,			/* Owner widget */
-	GdkAtom selection_atom,		/* Selection */
-	gulong t,			/* Time */
-	const guint8 *data, gint length
+	GtkWidget *w,
+	GdkAtom selection_atom,
+	const gulong t,
+	const guint8 *data, const gint length
 );
 extern guint8 *GUIDDEGetBinary(
-	GtkWidget *w,			/* Widget making request */
-	GdkAtom selection_atom,		/* Can be GDK_NONE */
-	gulong t,			/* Time */
+	GtkWidget *w,
+	GdkAtom selection_atom,
+	const gulong t,
 	gint *length
 );
 extern void GUIDDESetString(
-	GtkWidget *w,			/* Owner widget */
-	GdkAtom selection_atom,		/* Selection */
-	gulong t,			/* Time */
+	GtkWidget *w,
+	GdkAtom selection_atom,
+	const gulong t,
 	const gchar *data
 );
 extern gchar *GUIDDEGetString(
-	GtkWidget *w,			/* Widget making request */
-	GdkAtom selection_atom,		/* Can be GDK_NONE */
-	gulong t			/* Time */
+	GtkWidget *w,
+	GdkAtom selection_atom,
+	const gulong t
 );
 
 
@@ -591,8 +655,8 @@ extern void GUIMenuItemSetSubMenu(
 /* Pull Out Window */
 extern void *GUIPullOutCreateH(
 	void *parent_box,
-	int homogeneous, int spacing,           /* Of client vbox */
-	int expand, int fill, int padding,      /* Of holder hbox */
+	int homogeneous, int spacing,		/* Of client vbox */
+	int expand, int fill, int padding,	/* Of holder hbox */
 	int toplevel_width, int toplevel_height,
 	void *pull_out_client_data,
 	void (*pull_out_cb)(void *, void *),
