@@ -10,6 +10,7 @@
 #include "../../include/disk.h"
 
 #include "../guiutils.h"
+#include "../fprompt.h"
 #include "../cdialog.h"
 #include "../fb.h"
 #include "../pdialog.h"
@@ -135,7 +136,7 @@ static void HEditUpdate(hedit_struct *he);
  /* Check if current data has modifications and		\
   * if so, query user to save first			\
   */							\
- if(((_hv_) != NULL) ? (_hv_)->modified : FALSE) {	\
+ if(((_hv_) != NULL) ? ((_hv_)->flags & HVIEW_FLAG_HAS_CHANGES) : FALSE) { \
   gint response;					\
 							\
   EDVPlaySoundQuestion((_he_)->ctx);			\
@@ -144,17 +145,11 @@ static void HEditUpdate(hedit_struct *he);
 "Save Changes?",					\
 "The data contains changes that have not been\n\
 saved, do you want to save those changes?", \
-"There are changes made to the data that have\n\
-not been saved. If you want to save those changes,\n\
-then click on \"Yes\". If you want to discard\n\
-those changes then click on \"No\". If you do not\n\
-want to continue with this operation then click\n\
-on \"Cancel\".",					\
+   NULL,						\
    CDIALOG_ICON_WARNING,				\
    CDIALOG_BTNFLAG_YES |				\
    CDIALOG_BTNFLAG_NO |					\
-   CDIALOG_BTNFLAG_CANCEL |				\
-   CDIALOG_BTNFLAG_HELP,				\
+   CDIALOG_BTNFLAG_CANCEL,				\
    CDIALOG_BTNFLAG_YES					\
   );							\
   CDialogSetTransientFor(NULL);				\
@@ -163,7 +158,7 @@ on \"Cancel\".",					\
    case CDIALOG_RESPONSE_YES:				\
     HEditSaveCB(NULL, data);				\
     /* Check if changes were not saved? */		\
-    if((_hv_)->modified)				\
+    if((_hv_)->flags & HVIEW_FLAG_HAS_CHANGES)		\
      return;						\
     break;						\
 							\
@@ -352,7 +347,7 @@ static void HEditNewCB(GtkWidget *widget, gpointer data)
 
 	HViewClear(hv);
 
-	hv->modified = FALSE;
+	hv->flags &= ~HVIEW_FLAG_HAS_CHANGES;
 
 	g_free(he->filename);
 	he->filename = NULL;
@@ -474,11 +469,9 @@ static void HEditSaveCB(GtkWidget *widget, gpointer data)
 	    CDialogGetResponse(
 		"Save Error",
 		buf,
-"Please check if you have sufficient permission to\n\
-save to the specified file and that the device capacity\n\
-has not been exceeded.",
+		NULL,
 		CDIALOG_ICON_ERROR,
-		CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
+		CDIALOG_BTNFLAG_OK,
 		CDIALOG_BTNFLAG_OK
 	    );
 	    CDialogSetTransientFor(NULL);
@@ -492,7 +485,7 @@ has not been exceeded.",
 	    );
 	    EDVContextSync(he->ctx);
 
-	    hv->modified = FALSE;
+	    hv->flags &= ~HVIEW_FLAG_HAS_CHANGES;
 	}
 
 	HEditUpdate(he);
@@ -610,11 +603,9 @@ static void HEditSaveAsCB(GtkWidget *widget, gpointer data)
 			CDialogGetResponse(
 			    "Save Error",
 			    buf,
-"Please check if you have sufficient permission to\n\
-save to the specified file and that the disk capacity\n\
-has not been exceeded.",
+			    NULL,
 			    CDIALOG_ICON_ERROR,
-			    CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
+			    CDIALOG_BTNFLAG_OK,
 			    CDIALOG_BTNFLAG_OK
 			);
 			CDialogSetTransientFor(NULL);
@@ -633,7 +624,7 @@ has not been exceeded.",
 			    );
 			EDVContextSync(he->ctx);
 
-			hv->modified = FALSE;
+			hv->flags &= ~HVIEW_FLAG_HAS_CHANGES;
 		    }
 		}
 	    }
@@ -1837,7 +1828,7 @@ static void HEditUpdate(hedit_struct *he)
 		PROG_NAME_FULL ": %s%s",
 		(s != NULL) ? s + 1 :
 		    ((he->filename != NULL) ? he->filename : "Untitled"),
-		hv->modified ? " (*)" : ""
+		HVIEW_HAS_CHANGES(hv) ? " (*)" : ""
 	    );
 	    gtk_window_set_title(GTK_WINDOW(w), title);
 	    g_free(title);
@@ -2024,6 +2015,7 @@ int main(int argc, char *argv[])
 	gdk_rgb_init();
 
 	/* Initialize dialogs */
+	FPromptInit();
 	CDialogInit();
 	FileBrowserInit();
 	PDialogInit();
@@ -2202,9 +2194,10 @@ int main(int argc, char *argv[])
 	ctx = NULL;
 
 	/* Shutdown dialogs */
-	CDialogShutdown();
-	FileBrowserShutdown();
 	PDialogShutdown();
+	FileBrowserShutdown();
+	CDialogShutdown();
+	FPromptShutdown();
 
 	/* Reset the DND Icon */
 	GUIDNDSetDragIcon(NULL, NULL, 0, 0);
