@@ -22,9 +22,17 @@
 #include "images/icon_edit_48x48.xpm"
 
 
-gint HViewPositionXYToBuffer(hview_struct *hv, gint x, gint y);
-void HViewScrollTo(hview_struct *hv, gint pos, gfloat ycoeff);
-GtkVisibility HViewIsBufferPositionVisible(hview_struct *hv, gint i);
+gint HViewPositionXYToBuffer(
+	hview_struct *hv,
+	const gint x, const gint y
+);
+void HViewScrollTo(
+	hview_struct *hv,
+	const gint pos, const gfloat ycoeff
+);
+GtkVisibility HViewIsBufferPositionVisible(
+	hview_struct *hv, const gint i
+);
 
 gint HViewOpenFileProgress(
 	hview_struct *hv, const gchar *path,
@@ -60,8 +68,8 @@ void HViewPaste(hview_struct *hv);
 void HViewInsert(hview_struct *hv);
 void HViewDeleteSelected(hview_struct *hv);
 gint HViewFind(
-	hview_struct *hv, const guint8 *needle, gint needle_len,
-	gint start_pos, gboolean case_sensitive
+	hview_struct *hv, const guint8 *needle, const gint needle_len,
+	const gint start_pos, const gboolean case_sensitive
 );
 
 gboolean HViewToplevelIsWindow(hview_struct *hv);
@@ -73,9 +81,9 @@ hview_struct *HViewNew(GtkWidget *parent);
 hview_struct *HViewNewWithToplevel(
 	gint width, gint height
 );
-void HViewShowHeading(hview_struct *hv, gboolean show);
-void HViewShowStatusBar(hview_struct *hv, gboolean show);
-void HViewSetReadOnly(hview_struct *hv, gboolean read_only);
+void HViewShowHeading(hview_struct *hv, const gboolean show);
+void HViewShowStatusBar(hview_struct *hv, const gboolean show);
+void HViewSetReadOnly(hview_struct *hv, const gboolean read_only);
 void HViewSetChangedCB(
 	hview_struct *hv,
 	void (*changed_cb)(hview_struct *, gpointer),
@@ -135,7 +143,10 @@ void HViewDelete(hview_struct *hv);
  *	coordinates relative to the hv's view widget.  The current
  *	hv's scroll position will be taken into account.
  */
-gint HViewPositionXYToBuffer(hview_struct *hv, gint x, gint y)
+gint HViewPositionXYToBuffer(
+	hview_struct *hv,
+	const gint x, const gint y
+)
 {
 	GtkAdjustment *adj;
 
@@ -216,9 +227,11 @@ gint HViewPositionXYToBuffer(hview_struct *hv, gint x, gint y)
  *	ycoeff.  This function does not update the buf_pos.
  */
 void HViewScrollTo(
-	hview_struct *hv, gint pos, gfloat ycoeff
+	hview_struct *hv,
+	const gint pos, const gfloat ycoeff
 )
 {
+	gint _pos = pos;
 	gint ww, wh;
 	GtkAdjustment *adj;
 	GtkWidget *w = (hv != NULL) ? hv->view_da : NULL;
@@ -236,12 +249,12 @@ void HViewScrollTo(
 	)
 	    return;
 
-	if(pos >= hv->buf_len)
-	    pos = hv->buf_len - 1;
-	if(pos < 0)
-	    pos = 0;
+	if(_pos >= hv->buf_len)
+	    _pos = hv->buf_len - 1;
+	if(_pos < 0)
+	    _pos = 0;
 
-	adj->value = ((pos / hv->cells_per_row) * hv->cell_height) -
+	adj->value = ((_pos / hv->cells_per_row) * hv->cell_height) -
 	    (ycoeff * MAX(adj->page_size - hv->cell_height, 0));
 	if(adj->value > (adj->upper - adj->page_size))
 	    adj->value = adj->upper - adj->page_size;
@@ -255,7 +268,9 @@ void HViewScrollTo(
  *	Returns one of GTK_VISIBILITY_* depending on if the given
  *	buffer position is is visible or not.
  */
-GtkVisibility HViewIsBufferPositionVisible(hview_struct *hv, gint i)
+GtkVisibility HViewIsBufferPositionVisible(
+	hview_struct *hv, const gint i
+)
 {
 	gint y, ww, wh;
 	GtkAdjustment *adj;
@@ -729,7 +744,7 @@ void HViewClear(hview_struct *hv)
 	if(adj == NULL)
 	    return;
 
-	/* Clear buffer and reset scroll position */
+	/* Clear the buffer and reset the scroll position */
 	g_free(hv->buf);
 	hv->buf = NULL;
 	hv->buf_pos = 0;
@@ -738,8 +753,9 @@ void HViewClear(hview_struct *hv)
 	hv->buf_sel_end = -1;
 	hv->edit_buf_i = 0;
 	*hv->edit_buf = '\0';
-	changed = (hv->modified != FALSE) ? TRUE : FALSE;
-	hv->modified = FALSE;
+
+	changed = HVIEW_HAS_CHANGES(hv);
+	hv->flags &= ~HVIEW_FLAG_HAS_CHANGES;
 
 	adj->value = 0.0f;
 
@@ -1020,10 +1036,11 @@ void HViewDeleteSelected(hview_struct *hv)
  *	cannot be found at or after the start_pos.
  */
 gint HViewFind(
-	hview_struct *hv, const guint8 *needle, gint needle_len,
-	gint start_pos, gboolean case_sensitive
+	hview_struct *hv, const guint8 *needle, const gint needle_len,
+	const gint start_pos, const gboolean case_sensitive
 )
 {
+	gint _start_pos = start_pos;
 	gint i;
 	const guint8 *buf;
 	gint buf_len;
@@ -1036,10 +1053,10 @@ gint HViewFind(
 	if((buf == NULL) || (buf_len <= 0))
 	    return(-1);
 
-	if(start_pos < 0)
-	    start_pos = 0;
+	if(_start_pos < 0)
+	    _start_pos = 0;
 
-	i = start_pos;
+	i = _start_pos;
 	while(i < buf_len)
 	{
 	    /* First character of needle matches current buffer
@@ -1131,23 +1148,19 @@ hview_struct *HViewNew(GtkWidget *parent)
 	if(hv == NULL)
 	    return(NULL);
 
-	/* Reset values */
 	hv->map_state = FALSE;
 	hv->freeze_count = 0;
 	hv->busy_count = 0;
-	hv->dragging_selection = FALSE;
-	hv->dragging_scroll = FALSE;
+	hv->flags = 0;
 	hv->scroll_toid = 0;
 	hv->buf = NULL;
 	hv->buf_pos = 0;
 	hv->buf_len = 0;
 	hv->buf_sel_start = -1;
 	hv->buf_sel_end = -1;
-	hv->read_only = FALSE;
 	hv->edit_mode = HVIEW_EDIT_MODE_HEX;
 	hv->edit_buf_i = 0;
 	*hv->edit_buf = '\0';
-	hv->modified = FALSE;
 	hv->changed_cb = NULL;
 	hv->changed_data = NULL;
 	hv->select_cb = NULL;
@@ -1682,7 +1695,7 @@ hview_struct *HViewNewWithToplevel(
 /*
  *	Shows or hides the Hex View's Heading.
  */
-void HViewShowHeading(hview_struct *hv, gboolean show)
+void HViewShowHeading(hview_struct *hv, const gboolean show)
 {
 	GtkWidget *w;
 
@@ -1702,7 +1715,7 @@ void HViewShowHeading(hview_struct *hv, gboolean show)
 /*
  *	Shows or hides the Hex View's Status Bar.
  */
-void HViewShowStatusBar(hview_struct *hv, gboolean show)
+void HViewShowStatusBar(hview_struct *hv, const gboolean show)
 {
 	GtkWidget *w;
 
@@ -1722,14 +1735,18 @@ void HViewShowStatusBar(hview_struct *hv, gboolean show)
 /*
  *	Sets the Hex View's as read only or writable.
  */
-void HViewSetReadOnly(hview_struct *hv, gboolean read_only)
+void HViewSetReadOnly(hview_struct *hv, const gboolean read_only)
 {
 	if(hv == NULL)
 	    return;
 
-	if(hv->read_only != read_only)
+	if(HVIEW_READ_ONLY(hv) != read_only)
 	{
-	    hv->read_only = read_only;
+	    if(read_only)
+		hv->flags |= HVIEW_FLAG_READ_ONLY;
+	    else
+		hv->flags &= ~HVIEW_FLAG_READ_ONLY;
+
 	    HViewQueueDraw(hv);
 	    HViewUpdate(hv);
 	}
@@ -1797,26 +1814,28 @@ void HViewSetEditModeChangedCB(
  */
 void HViewUpdate(hview_struct *hv)
 {
-	gboolean sensitive;
+	gboolean read_only, sensitive;
 
 	if(hv == NULL)
 	    return;
 
 	hv->freeze_count++;
 
+	read_only = HVIEW_READ_ONLY(hv);
+
 	/* Right click menu */
 
 	/* Cut, Copy and Paste */
-	sensitive = hv->read_only ?
+	sensitive = read_only ?
 	    FALSE : HVIEW_IS_BUF_SELECTED(hv);
 	GTK_WIDGET_SET_SENSITIVE(hv->cut_mi, sensitive)
 	sensitive = (HVIEW_IS_BUF_SELECTED(hv)) ? TRUE : FALSE;
 	GTK_WIDGET_SET_SENSITIVE(hv->copy_mi, sensitive)
-	sensitive = !hv->read_only;
+	sensitive = !read_only;
 	GTK_WIDGET_SET_SENSITIVE(hv->paste_mi, sensitive) 
 
 	/* Insert and Delete */
-	sensitive = !hv->read_only;
+	sensitive = !read_only;
 	GTK_WIDGET_SET_SENSITIVE(hv->insert_mi, sensitive) 
 	GTK_WIDGET_SET_SENSITIVE(hv->delete_mi, sensitive) 
 
@@ -1827,7 +1846,7 @@ void HViewUpdate(hview_struct *hv)
 	GTK_WIDGET_SET_SENSITIVE(hv->unselect_all_mi, sensitive)
 
 	/* Edit mode */
-	if(hv->read_only)
+	if(HVIEW_READ_ONLY(hv))
 	{
 	    gtk_widget_hide(hv->edit_mode_msep);
 	    gtk_widget_hide(hv->edit_mode_hex_mi);
