@@ -7,18 +7,21 @@
 
 #include <gtk/gtk.h>
 #include "cfg.h"
-#include "edvtypes.h"
 #include "toolbar.h"
-#include "mountbar.h"
-#include "findbar.h"
 #include "tlist.h"
 #include "imgview.h"
-#include "statusbar.h"
-#include "fopdlg.h"
+#include "edv_types.h"
+#include "edv_mime_type.h"
+#include "edv_mount_bar.h"
+#include "edv_find_bar.h"
+#include "edv_status_bar.h"
+#include "obj_op_dlg.h"
 
 
 typedef struct _edv_imbr_struct		edv_imbr_struct;
+#define EDV_IMBR(p)			((edv_imbr_struct *)(p))
 typedef struct _edv_imbr_opid_struct	edv_imbr_opid_struct;
+#define EDV_IMBR_OPID(p)		((edv_imbr_opid_struct *)(p))
 
 
 /*
@@ -33,10 +36,12 @@ typedef enum {
 	EDV_IMBR_OP_EXIT			= 201,
 
 	EDV_IMBR_OP_SYNC_DISKS			= 300,
-        EDV_IMBR_OP_HISTORY			= 301,
+	EDV_IMBR_OP_HISTORY			= 301,
 	EDV_IMBR_OP_RUN				= 302,
 	EDV_IMBR_OP_RUN_TERMINAL		= 303,
 	EDV_IMBR_OP_WRITE_PROTECT		= 304,
+	EDV_IMBR_OP_DELETE_METHOD_RECYCLE	= 308,
+	EDV_IMBR_OP_DELETE_METHOD_PURGE		= 309,
 
 	EDV_IMBR_OP_NEW				= 400,
 	EDV_IMBR_OP_NEW_FILE			= 401,
@@ -48,11 +53,12 @@ typedef enum {
 	EDV_IMBR_OP_NEW_SOCKET			= 407,
 
 	EDV_IMBR_OP_OPEN			= 500,
-	EDV_IMBR_OP_OPEN_WITH			= 501,
+	EDV_IMBR_OP_OPEN_TO			= 501,
+	EDV_IMBR_OP_OPEN_WITH			= 502,
 
-        EDV_IMBR_OP_COPY_PATH			= 600,
-        EDV_IMBR_OP_COPY_URL			= 601,
-        EDV_IMBR_OP_PASTE			= 610,
+	EDV_IMBR_OP_COPY_PATH			= 600,
+	EDV_IMBR_OP_COPY_URL			= 601,
+	EDV_IMBR_OP_PASTE			= 610,
 
 	EDV_IMBR_OP_MOVE			= 700,
 	EDV_IMBR_OP_COPY			= 701,
@@ -60,20 +66,21 @@ typedef enum {
 	EDV_IMBR_OP_RENAME			= 703,
 	EDV_IMBR_OP_CHMOD			= 704,
 	EDV_IMBR_OP_CHOWN			= 705,
-	EDV_IMBR_OP_DELETE			= 706,
-	EDV_IMBR_OP_PROPERTIES			= 707,
+	EDV_IMBR_OP_CHTIME			= 706,
+	EDV_IMBR_OP_DELETE			= 770,
+	EDV_IMBR_OP_PROPERTIES			= 780,
 
-        EDV_IMBR_OP_SELECT_ALL			= 800,
-        EDV_IMBR_OP_UNSELECT_ALL		= 801,
-        EDV_IMBR_OP_INVERT_SELECTION		= 802,
+	EDV_IMBR_OP_SELECT_ALL			= 800,
+	EDV_IMBR_OP_UNSELECT_ALL		= 801,
+	EDV_IMBR_OP_INVERT_SELECTION		= 802,
 	EDV_IMBR_OP_FIND			= 850,
 
-        EDV_IMBR_OP_DOWNLOAD			= 900,
+	EDV_IMBR_OP_DOWNLOAD			= 900,
 
 	EDV_IMBR_OP_REFRESH			= 1000,
 	EDV_IMBR_OP_REFRESH_ALL			= 1001,
-        EDV_IMBR_OP_GOTO_PARENT			= 1100,
-        EDV_IMBR_OP_GOTO_HOME			= 1101,
+	EDV_IMBR_OP_GOTO_PARENT			= 1100,
+	EDV_IMBR_OP_GOTO_HOME			= 1101,
 	EDV_IMBR_OP_STOP			= 1200,
 	EDV_IMBR_OP_CONTINUE			= 1201,
 	EDV_IMBR_OP_PRESENTATION_MODE		= 1280,
@@ -84,15 +91,16 @@ typedef enum {
 	EDV_IMBR_OP_SHOW_FIND_BAR		= 1303,
 	EDV_IMBR_OP_SHOW_STATUS_BAR		= 1304,
 
-	EDV_IMBR_OP_SHOW_HIDDEN_OBJECTS		= 1401,
-	EDV_IMBR_OP_SHOW_NOACCESS_OBJECTS	= 1402,
-	EDV_IMBR_OP_SHOW_NONIMAGE_OBJECTS	= 1403,
+	EDV_IMBR_OP_THUMBS_LIST_FILTER		= 1400,
+	EDV_IMBR_OP_SHOW_HIDDEN_OBJECTS		= 1420,
+	EDV_IMBR_OP_SHOW_NOACCESS_OBJECTS	= 1421,
+	EDV_IMBR_OP_SHOW_NONIMAGE_OBJECTS	= 1422,
 
-        EDV_IMBR_OP_MOUNT			= 1600,	/* Mount/unmount */
-        EDV_IMBR_OP_EJECT			= 1620,
-        EDV_IMBR_OP_DEVICE_CHECK		= 1650,
-        EDV_IMBR_OP_DEVICE_TOOLS		= 1651,
-        EDV_IMBR_OP_DEVICE_FORMAT		= 1652,
+	EDV_IMBR_OP_MOUNT			= 1600,	/* Mount/unmount */
+	EDV_IMBR_OP_EJECT			= 1620,
+	EDV_IMBR_OP_DEVICE_CHECK		= 1650,
+	EDV_IMBR_OP_DEVICE_TOOLS		= 1651,
+	EDV_IMBR_OP_DEVICE_FORMAT		= 1652,
 
 	EDV_IMBR_OP_MIME_TYPES			= 1700,
 	EDV_IMBR_OP_DEVICES			= 1701,
@@ -114,7 +122,7 @@ typedef enum {
 	EDV_IMBR_OP_HELP_MIME_TYPES		= 3051,
 	EDV_IMBR_OP_HELP_DEVICES		= 3052,
 	EDV_IMBR_OP_HELP_COMMON_OPERATIONS	= 3053,
-        EDV_IMBR_OP_HELP_ABOUT			= 3100
+	EDV_IMBR_OP_HELP_ABOUT			= 3100
 
 } edv_imbr_op;
 
@@ -159,7 +167,7 @@ struct _edv_imbr_opid_struct {
 			**menu_icon_data;	/* Shared */
 
 };
-#define EDV_IMBR_OPID(p)	((edv_imbr_opid_struct *)(p))
+
 
 /*
  *	Image Browser:
@@ -171,7 +179,7 @@ struct _edv_imbr_struct {
 	gint		busy_count,
 			passive_busy_count,
 			freeze_count;
-	gpointer	core_ptr;
+	edv_core_struct	*core;
 
 	GList		*opid_list;
 
@@ -203,9 +211,11 @@ struct _edv_imbr_struct {
 
 	/* Menu Bar Items */
 	GtkWidget	*open_mi,
+			*open_to_mi,
+			*open_to_menu,
 			*open_with_mi,
-			*new_object_submi,
-			*new_object_submenu,
+			*new_object_mi,
+			*new_object_menu,
 			*new_file_mi,
 			*new_directory_mi,
 			*new_link_mi,
@@ -224,6 +234,7 @@ struct _edv_imbr_struct {
 			*rename_mi,
 			*chmod_mi,
 			*chown_mi,
+			*chtime_mi,
 			*delete_mi,
 			*copy_path_mi,
 			*copy_url_mi,
@@ -251,12 +262,15 @@ struct _edv_imbr_struct {
 			*show_mount_bar_micheck,
 			*show_find_bar_micheck,
 			*show_status_bar_micheck,
+			*thumbs_list_filter_mi,
 			*show_hidden_objects_micheck,
 			*show_noaccess_objects_micheck,
 			*show_nonimage_objects_micheck,
 			*mime_types_mi,
 
 			*write_protect_mi,
+			*delete_method_recycle_micheck,
+			*delete_method_purge_micheck,
 			*options_mi,
 			*customize_mi,
 
@@ -273,14 +287,14 @@ struct _edv_imbr_struct {
 			*help_common_operations_mi,
 			*help_about_mi;
 
-        /* Tool Bar */
-        toolbar_struct	*tool_bar;
+	/* Tool Bar */
+	toolbar_struct	*tool_bar;
 
-        /* Mount Bar */
-        edv_mountbar_struct	*mount_bar;
+	/* Mount Bar */
+	edv_mount_bar_struct	*mount_bar;
 
-        /* Find Bar */
-        edv_findbar_struct	*find_bar;
+	/* Find Bar */
+	edv_findbar_struct	*find_bar;
 
 	/* Thumbs List */
 	tlist_struct	*tlist;
@@ -292,6 +306,8 @@ struct _edv_imbr_struct {
 	/* Right-click menu */
 	GtkWidget	*tlist_menu,
 			*tlist_open_mi,
+			*tlist_open_to_mi,
+			*tlist_open_to_menu,
 			*tlist_open_with_mi,
 			*tlist_mount_mi,
 			*tlist_eject_mi,
@@ -302,12 +318,16 @@ struct _edv_imbr_struct {
 			*tlist_rename_mi,
 			*tlist_chmod_mi,
 			*tlist_chown_mi,
+			*tlist_chtime_mi,
 			*tlist_delete_mi,
 			*tlist_copy_path_mi,
 			*tlist_copy_url_mi,
 			*tlist_paste_mi,
 			*tlist_properties_mi;
 
+	/* Thumbs list filter */
+	gchar		*thumbs_list_filter;
+
 	/* Icons used in the thumbs list */
 	GdkPixmap	*folder_parent_pixmap;
 	GdkBitmap	*folder_parent_mask;
@@ -345,14 +365,13 @@ struct _edv_imbr_struct {
 
 
 	/* Status Bar */
-	edv_statusbar_struct	*status_bar;
+	edv_status_bar_struct	*status_bar;
 
 
-	/* File Operation Dialog */
-	edv_fopdlg_struct	*fopdlg;
+	/* Object Operations Dialog */
+	edv_obj_op_dlg_struct	*obj_op_dlg;
 
 };
-#define EDV_IMBR(p)	((edv_imbr_struct *)(p))
 
 
 extern edv_imbr_opid_struct *EDVImbrMatchOPID(
@@ -373,6 +392,9 @@ extern void EDVImbrUpdateLocationIcon(
 extern void EDVImbrAccelkeysRegenerate(edv_imbr_struct *imbr);
 extern void EDVImbrToolbarRegenerate(edv_imbr_struct *imbr);
 extern void EDVImbrNewObjectMenuRegenerate(edv_imbr_struct *imbr);
+extern void EDVImbrOpenToMenuRegenerate(
+	edv_imbr_struct *imbr, edv_mime_type_struct *m
+);
 extern void EDVImbrTListMenuRegenerate(edv_imbr_struct *imbr);
 
 extern void EDVImbrSyncConfiguration(edv_imbr_struct *imbr);
@@ -390,7 +412,7 @@ extern void EDVImbrOPIDListDelete(GList *glist);
 
 extern cfg_accelkey_list_struct *EDVImbrAccelkeysListNewDefault(void);
 
-extern edv_imbr_struct *EDVImbrNew(gpointer core_ptr);
+extern edv_imbr_struct *EDVImbrNew(edv_core_struct *core);
 extern void EDVImbrSyncData(edv_imbr_struct *imbr);
 extern void EDVImbrUpdateMenus(edv_imbr_struct *imbr);
 extern void EDVImbrSetBusy(edv_imbr_struct *imbr, gboolean busy);
