@@ -107,9 +107,9 @@ static void EDVImbrDNDUpdateStatusBar(
 	    return;
 
 	/* Format the status bar message */
-	if((info == EDV_DND_TYPE_INFO_TEXT_PLAIN) ||
-	   (info == EDV_DND_TYPE_INFO_TEXT_URI_LIST) ||
-	   (info == EDV_DND_TYPE_INFO_STRING)
+	if((info == EDV_DND_INFO_TEXT_PLAIN) ||
+	   (info == EDV_DND_INFO_TEXT_URI_LIST) ||
+	   (info == EDV_DND_INFO_STRING)
 	)
 	{
 	    switch(gdk_action)
@@ -167,7 +167,7 @@ static void EDVImbrDNDUpdateStatusBar(
 		break;
 	    }
 	}
-	else if(info == EDV_DND_TYPE_INFO_RECYCLED_OBJECT)
+	else if(info == EDV_DND_INFO_RECYCLED_OBJECT)
 	{
 	    switch(gdk_action)
 	    {
@@ -192,7 +192,7 @@ static void EDVImbrDNDUpdateStatusBar(
 		break;
 	    }
 	}
-	else if(info == EDV_DND_TYPE_INFO_ARCHIVE_OBJECT)
+	else if(info == EDV_DND_INFO_ARCHIVE_OBJECT)
 	{
 	    switch(gdk_action)
 	    {
@@ -290,7 +290,7 @@ static void EDVImbrDragDataReceivedNexus(
 	 * that have a url with a http or ftp protocol
 	 */
 	url = (url_list != NULL) ? URL(url_list->data) : NULL;
-	if((url != NULL) ? !STRISEMPTY(url->path) : FALSE)
+	if((url != NULL) ? !STRISEMPTY(url->protocol) : FALSE)
 	{
 	    const gchar *protocol = url->protocol;
 	    if(!g_strcasecmp(protocol, "http") ||
@@ -319,9 +319,9 @@ static void EDVImbrDragDataReceivedNexus(
 	);
 	/* User confirmed and dnd target type is a disk object? */
 	if((initial_confirmation_result == CDIALOG_RESPONSE_YES) &&
-	   ((info == EDV_DND_TYPE_INFO_TEXT_PLAIN) ||
-	    (info == EDV_DND_TYPE_INFO_TEXT_URI_LIST) ||
-	    (info == EDV_DND_TYPE_INFO_STRING)
+	   ((info == EDV_DND_INFO_TEXT_PLAIN) ||
+	    (info == EDV_DND_INFO_TEXT_URI_LIST) ||
+	    (info == EDV_DND_INFO_STRING)
 	   )
 	)
 	{
@@ -463,7 +463,7 @@ static void EDVImbrDragDataReceivedNexus(
 	}
 	/* User confirmed and dnd target type is a recycled object? */
 	else if((initial_confirmation_result == CDIALOG_RESPONSE_YES) &&
-		(info == EDV_DND_TYPE_INFO_RECYCLED_OBJECT)
+		(info == EDV_DND_INFO_RECYCLED_OBJECT)
 	)
 	{
 	    struct stat lstat_buf;
@@ -578,7 +578,7 @@ static void EDVImbrDragDataReceivedNexus(
 	}
 	/* User confirmed and dnd target type is an archive object? */
 	else if((initial_confirmation_result == CDIALOG_RESPONSE_YES) &&
-		(info == EDV_DND_TYPE_INFO_ARCHIVE_OBJECT)
+		(info == EDV_DND_INFO_ARCHIVE_OBJECT)
 	)
 	{
 	    gboolean	yes_to_all = FALSE;
