@@ -495,7 +495,8 @@ GList *EDVImbrTListLoadImageRGBA(
 		    imlib_image->rgb_data,
 		    swidth, sheight, -1,
 		    t_rgb,
-		    twidth, theight, -1
+		    twidth, theight, -1,
+		    NULL, NULL
 		);
 	    if(t_alpha != NULL)
 		GUIImageBufferResize(
@@ -503,7 +504,8 @@ GList *EDVImbrTListLoadImageRGBA(
 		    imlib_image->alpha_data,
 		    swidth, sheight, -1,
 		    t_alpha,
-		    twidth, theight, -1
+		    twidth, theight, -1,
+		    NULL, NULL
 		);
 
 	    /* Create RGBA image data from the resized thumb RGBA
