@@ -9,9 +9,41 @@
 
 
 typedef struct _imgview_struct		imgview_struct;
+#define IMGVIEW(p)			((imgview_struct *)(p))
 typedef struct _imgview_frame_struct    imgview_frame_struct;
+#define IMGVIEW_FRAME(p)		((imgview_frame_struct *)(p))
 typedef struct _imgview_image_struct	imgview_image_struct;
+#define IMGVIEW_IMAGE(p)		((imgview_image_struct *)(p))
 typedef struct _imgview_cropdlg_struct	imgview_cropdlg_struct;
+#define IMGVIEW_CROPDLG(p)		((imgview_cropdlg_struct *)(p))
+
+
+/*
+ *	Flags:
+ */
+typedef enum {
+
+	/* Toplevel widget is a GtkWindow, otherwise it is a
+	 * GtkContainer */
+	IMGVIEW_FLAG_TOPLEVEL_IS_WINDOW	= (1 << 0),
+
+	/* Specifies if geometry, zoom, zoom rectangular, etc values
+	 * should be shown */
+	IMGVIEW_FLAG_VALUES_SHOWABLE	= (1 << 1),
+	IMGVIEW_FLAG_SHOW_VALUES	= (1 << 2),
+
+	/* Specifies to display the contents of the ImgView on the
+	 * WM Icon? */
+	IMGVIEW_FLAG_SHOW_IMAGE_ON_WM_ICON = (1 << 4),
+
+	IMGVIEW_FLAG_TOOL_BAR_SHOWABLE	= (1 << 8),
+	IMGVIEW_FLAG_TOOL_BAR_MAPPED	= (1 << 9),
+	IMGVIEW_FLAG_MENU_BUTTON_SHOWABLE = (1 << 10),
+	IMGVIEW_FLAG_MENU_BUTTON_MAPPED	= (1 << 11),
+	IMGVIEW_FLAG_STATUS_BAR_SHOWABLE = (1 << 12),
+	IMGVIEW_FLAG_STATUS_BAR_MAPPED	= (1 << 13)
+
+} imgview_flags;
 
 
 /*
@@ -30,12 +62,12 @@ typedef enum {
  *	Image Data Formats:
  */
 typedef enum {
-	IMGVIEW_FORMAT_GREYSCALE8		= 10,	/* 1 bpp */
-	IMGVIEW_FORMAT_GREYSCALE16		= 11,	/* 2 bpp */
-	IMGVIEW_FORMAT_GREYSCALE32		= 12,	/* 4 bpp */
-	IMGVIEW_FORMAT_GREYSCALEA32		= 13,	/* 4 bpp */
-	IMGVIEW_FORMAT_RGB			= 20,	/* 3 bpp */
-	IMGVIEW_FORMAT_RGBA			= 21	/* 4 bpp */
+	IMGVIEW_FORMAT_GREYSCALE8	= 10,	/* 1 bpp */
+	IMGVIEW_FORMAT_GREYSCALE16	= 11,	/* 2 bpp */
+	IMGVIEW_FORMAT_GREYSCALE32	= 12,	/* 4 bpp */
+	IMGVIEW_FORMAT_GREYSCALEA32	= 13,	/* 4 bpp */
+	IMGVIEW_FORMAT_RGB		= 20,	/* 3 bpp */
+	IMGVIEW_FORMAT_RGBA		= 21	/* 4 bpp */
 } imgview_format;
 
 /*
@@ -44,32 +76,31 @@ typedef enum {
 typedef enum {
 
 	/* Alpha channel is defined and is not uniform */
-	IMGVIEW_ALPHA_DEFINED			= (1 << 0),
+	IMGVIEW_ALPHA_DEFINED		= (1 << 0),
 
 	/* Use thresholding instead of blending the alpha value */
-	IMGVIEW_ALPHA_THRESHOLD			= (1 << 1),
+	IMGVIEW_ALPHA_THRESHOLD		= (1 << 1),
 
 	/* Alpha values are inverted (0xff = transparent and 0x00
 	 * means solid) */
-	IMGVIEW_ALPHA_INVERTED			= (1 << 2)
+	IMGVIEW_ALPHA_INVERTED		= (1 << 2)
 
 } imgview_alpha_flags;        
 
-
 /*
  *	Crop Flags:
  */
 typedef enum {
 
 	/* Crop is allowed */
-	IMGVIEW_CROP_ALLOWED			= (1 << 0),
+	IMGVIEW_CROP_ALLOWED		= (1 << 0),
 
 	/* Crop rectangle defined (or is being defined) by user in the
 	 * middle of a drag crop rectangle */
-	IMGVIEW_CROP_DEFINED			= (1 << 1),
+	IMGVIEW_CROP_DEFINED		= (1 << 1),
 
 	/* Crop rectangle defined and finalized */
-	IMGVIEW_CROP_FINALIZED			= (1 << 2)
+	IMGVIEW_CROP_FINALIZED		= (1 << 2)
 
 } imgview_crop_flags;
 
@@ -83,7 +114,6 @@ struct _imgview_frame_struct {
 	gulong		delay;		/* Show this frame for this many ms */
 
 };
-#define IMGVIEW_FRAME(p)	((imgview_frame_struct *)(p))
 
 /*
  *	ImgView Image:
@@ -98,7 +128,6 @@ struct _imgview_image_struct {
 	gint		nframes;
 
 };
-#define IMGVIEW_IMAGE(p)	((imgview_image_struct *)(p))
 
 /*
  *	ImgView Crop Dialog:
@@ -117,7 +146,6 @@ struct _imgview_cropdlg_struct {
 	GdkRectangle	rect;		/* Crop Geometry */
 
 };
-#define IMGVIEW_CROPDLG(p)	((imgview_cropdlg_struct *)(p))
 
 /*
  *	ImgView:
@@ -130,18 +158,7 @@ struct _imgview_struct {
 	gint		freeze_count,
 			busy_count;
 
-	/* If this is a stand alone viewer window, then this will be
-	 * set to true, indicating toplevel is a GtkWindow (otherwise
-	 * toplevel will be a GtkContainer) */
-	gboolean	toplevel_is_window;
-
-	/* Specifies if geometry, zoom, zoom rectangular, etc values
-	 * should be drawn (including the geometry on the info_label) */
-	gboolean	show_values;
-
-	/* Specifies if a resized version of the image should be drawn
-	 * on to the WM icon when ImgViewLoad() is called */
-	gboolean	show_image_on_wm_icon;
+	imgview_flags	flags;
 
 	/* Quality, from 0 to 2
 	 *
@@ -202,8 +219,8 @@ struct _imgview_struct {
 	GdkBitmap	*wm_icon_mask;
 
 	/* Tool Bar */
-	gboolean	toolbar_map_state;
-	GtkWidget	*toolbar_toplevel,	/* GtkContainer */
+	GtkWidget	*tool_bar_toplevel,	/* GtkContainer */
+			*menu_button,
 			*info_label,		/* GtkDrawingArea */
 			*zoom_in_btn,
 			*zoom_out_btn,
@@ -215,8 +232,7 @@ struct _imgview_struct {
 			*vscrollbar;
 
 	/* Status Bar */
-	gboolean	statusbar_map_state;
-	GtkWidget	*statusbar_toplevel,	/* GtkContainer */
+	GtkWidget	*status_bar_toplevel,	/* GtkContainer */
 			*progress_bar;
 
 	/* Right-click menu */
@@ -238,10 +254,14 @@ struct _imgview_struct {
 			*mirror_vertical_mi;
 
 	/* Show submenut */
- 	GtkWidget	*show_menu,
-			*show_toolbar_micheck,
-			*show_values_micheck,
-			*show_statusbar_micheck;
+ 	GtkWidget	*view_menu,
+			*view_play_mi,
+			*view_pause_mi,
+			*view_prev_mi,
+			*view_next_mi,
+			*view_tool_bar_micheck,
+			*view_values_micheck,
+			*view_status_bar_micheck;
  
 	/* Quality submenu */
 	GtkWidget	*quality_menu,
@@ -280,7 +300,7 @@ struct _imgview_struct {
 	imgview_image_struct	*orig_img;
 
 	/* Current frame being displayed on the original image */
-	gint			orig_img_frame_num;
+	gint			cur_frame_num;
 
 	/* Draw next frame Timeout */
 	guint			next_frame_toid;
@@ -294,55 +314,83 @@ struct _imgview_struct {
 	gpointer	changed_data;
 
 };
-#define IMGVIEW(p)	((imgview_struct *)(p))
+
+#define IMGVIEW_IS_TOPLEVEL_WINDOW(_imgview_)	\
+ ((_imgview_)->flags & IMGVIEW_FLAG_TOPLEVEL_IS_WINDOW)
+
+#define IMGVIEW_VALUES_SHOWABLE(_imgview_)	\
+ ((_imgview_)->flags & IMGVIEW_FLAG_VALUES_SHOWABLE)
+#define IMGVIEW_SHOW_VALUES(_imgview_)		\
+ ((_imgview_)->flags & IMGVIEW_FLAG_SHOW_VALUES)
+
+#define IMGVIEW_SHOW_IMAGE_ON_WM_ICON(_imgview_) \
+ ((_imgview_)->flags & IMGVIEW_FLAG_SHOW_IMAGE_ON_WM_ICON)
+
+#define IMGVIEW_TOOL_BAR_SHOWABLE(_imgview_)	\
+ ((_imgview_)->flags & IMGVIEW_FLAG_TOOL_BAR_SHOWABLE)
+#define IMGVIEW_TOOL_BAR_MAPPED(_imgview_)	\
+ ((_imgview_)->flags & IMGVIEW_FLAG_TOOL_BAR_MAPPED)
+
+#define IMGVIEW_MENU_BUTTON_SHOWABLE(_imgview_)	\
+ ((_imgview_)->flags & IMGVIEW_FLAG_MENU_BUTTON_SHOWABLE)
+#define IMGVIEW_MENU_BUTTON_MAPPED(_imgview_)	\
+ ((_imgview_)->flags & IMGVIEW_FLAG_MENU_BUTTON_MAPPED)
+
+#define IMGVIEW_STATUS_BAR_SHOWABLE(_imgview_)	\
+ ((_imgview_)->flags & IMGVIEW_FLAG_STATUS_BAR_SHOWABLE)
+#define IMGVIEW_STATUS_BAR_MAPPED(_imgview_)	\
+ ((_imgview_)->flags & IMGVIEW_FLAG_STATUS_BAR_MAPPED)
 
 
 /* ImgView Image */
 extern imgview_image_struct *ImgViewImageNew(
-	gint width, gint height, gint bpp, gint bpl
+	const gint width, const gint height,
+	const gint bpp, const gint bpl
 );
 extern imgview_image_struct *ImgViewImageCopy(
 	imgview_image_struct *img
 );
 extern gint ImgViewImageInsertFrame(
-	imgview_image_struct *img, gint frame_num,
+	imgview_image_struct *img, const gint frame_num,
 	guint8 *buf,			/* Transfered */
-	gulong delay
+	const gulong delay
 );
 extern gint ImgViewImageAppendFrame(
 	imgview_image_struct *img,
 	guint8 *buf,			/* Transfered */
-	gulong delay
+	const gulong delay
 );
 extern gint ImgViewImageAppendFrameNew(imgview_image_struct *img);
 extern void ImgViewImageDeleteFrame(
-	imgview_image_struct *img, gint frame_num
+	imgview_image_struct *img, const gint frame_num
 );
 extern imgview_frame_struct *ImgViewImageGetFrame(
-	imgview_image_struct *img, gint frame_num
+	imgview_image_struct *img, const gint frame_num
 );
 extern void ImgViewImageClear(
-	imgview_image_struct *img, gint frame_num,
-	guint32 v
+	imgview_image_struct *img, const gint frame_num,
+	const guint32 v
 );
 extern void ImgViewImageSendRectangle(
-	imgview_image_struct *image, gint frame_num,
-	GdkDrawable *d, GdkGC *gc, gint quality,
+	imgview_image_struct *image, const gint frame_num,
+	GdkDrawable *d, GdkGC *gc,
+	const gint quality,
 	const GdkRectangle *rect
 );
 extern void ImgViewImageSend(
-	imgview_image_struct *image, gint frame_num,
-	GdkDrawable *d, GdkGC *gc, gint quality
+	imgview_image_struct *image, const gint frame_num,
+	GdkDrawable *d, GdkGC *gc,
+	const gint quality
 );
 extern void ImgViewImageDelete(imgview_image_struct *image);
 
 /* ImgView utilities */
-extern gint ImgViewConvertUnitViewToOrigX(imgview_struct *iv, gint x);
-extern gint ImgViewConvertUnitViewToOrigY(imgview_struct *iv, gint y);
-extern gint ImgViewConvertUnitOrigToViewX(imgview_struct *iv, gint x);
-extern gint ImgViewConvertUnitOrigToViewY(imgview_struct *iv, gint y);
+extern gint ImgViewConvertUnitViewToOrigX(imgview_struct *iv, const gint x);
+extern gint ImgViewConvertUnitViewToOrigY(imgview_struct *iv, const gint y);
+extern gint ImgViewConvertUnitOrigToViewX(imgview_struct *iv, const gint x);
+extern gint ImgViewConvertUnitOrigToViewY(imgview_struct *iv, const gint y);
 extern GtkAccelGroup *ImgViewGetAccelGroup(imgview_struct *iv);
-extern gboolean ImgViewToplevelIsWindow(imgview_struct *iv);
+extern gboolean ImgViewIsToplevelWindow(imgview_struct *iv);
 extern GtkWidget *ImgViewGetToplevelWidget(imgview_struct *iv);
 extern GtkDrawingArea *ImgViewGetViewWidget(imgview_struct *iv);
 extern GtkMenu *ImgViewGetMenuWidget(imgview_struct *iv);
@@ -383,16 +431,16 @@ extern gint ImgViewLoadToFit(
 
 extern void ImgViewPlay(imgview_struct *iv);
 extern void ImgViewPause(imgview_struct *iv);
-extern void ImgViewSeek(imgview_struct *iv, gint frame_num);
+extern void ImgViewSeek(imgview_struct *iv, const gint frame_num);
 extern gboolean ImgViewIsPlaying(imgview_struct *iv);
 
 extern imgview_struct *ImgViewNew(
-	gboolean show_toolbar,
-	gboolean show_values,
-	gboolean show_statusbar,
-	gboolean show_image_on_wm_icon,	/* Only if toplevel_is_window is TRUE */
-	gint quality,		/* 0 to 2 (2 being best/slowest) */
-	gboolean toplevel_is_window,
+	const gboolean show_toolbar,
+	const gboolean show_values,
+	const gboolean show_statusbar,
+	const gboolean show_image_on_wm_icon,
+	const gint quality,
+	const gboolean toplevel_is_window,
 	GtkWidget **toplevel_rtn
 );
 extern void ImgViewSetChangedCB(
@@ -410,12 +458,17 @@ extern void ImgViewQueueSendView(imgview_struct *iv);
 extern void ImgViewDraw(imgview_struct *iv);
 extern void ImgViewUpdateMenus(imgview_struct *iv);
 
-extern void ImgViewShowToolBar(imgview_struct *iv, gboolean show);
-extern void ImgViewShowStatusBar(imgview_struct *iv, gboolean show);
+extern void ImgViewSetValuesShowable(imgview_struct *iv, const gboolean b);
+extern void ImgViewSetToolBarShowable(imgview_struct *iv, const gboolean b);
+extern void ImgViewShowToolBar(imgview_struct *iv, const gboolean show);
+extern void ImgViewSetToolBarMenuShowable(imgview_struct *iv, const gboolean b);
+extern void ImgViewShowToolBarMenu(imgview_struct *iv, const gboolean show);
+extern void ImgViewSetStatusBarShowable(imgview_struct *iv, const gboolean b);
+extern void ImgViewShowStatusBar(imgview_struct *iv, const gboolean show);
 
 extern void ImgViewSetViewBG(
 	imgview_struct *iv,
-	GdkColor *c		/* 5 colors */
+	const GdkColor *c		/* 5 colors */
 );
 
 extern void ImgViewZoomIn(imgview_struct *iv);
@@ -424,10 +477,12 @@ extern void ImgViewZoomOneToOne(imgview_struct *iv);
 extern void ImgViewZoomToFit(imgview_struct *iv);
 extern void ImgViewZoomPrev(imgview_struct *iv);
 
-extern void ImgViewAllowCrop(imgview_struct *iv, gboolean allow_crop);
-extern void ImgViewSetBusy(imgview_struct *iv, gboolean busy);
+extern void ImgViewAllowCrop(imgview_struct *iv, const gboolean allow_crop);
+extern void ImgViewSetBusy(imgview_struct *iv, const gboolean busy);
 extern void ImgViewProgressUpdate(
-	imgview_struct *iv, gfloat position, gboolean allow_gtk_iteration
+	imgview_struct *iv,
+	const gfloat v,
+	const gboolean allow_gtk_iteration
 );
 extern void ImgViewMap(imgview_struct *iv);
 extern void ImgViewUnmap(imgview_struct *iv);
