@@ -37,6 +37,7 @@
 #include "images/icon_export_32x32.xpm"
 #include "images/icon_close_20x20.xpm"
 
+#include "images/icon_mimetypes_32x32.xpm"
 #include "images/icon_mimetypes_48x48.xpm"
 
 #include "images/icon_system_object_20x20.xpm"
@@ -114,7 +115,8 @@ void EDVMimeTypesListWinSetRow(
 	edv_mime_type_struct *m
 );
 void EDVMimeTypesListWinFetchValues(
-	edv_mime_types_list_win_struct *lw
+	edv_mime_types_list_win_struct *lw,
+	const gboolean verbose
 );
 
 void EDVMimeTypesListWinEdit(
@@ -191,7 +193,7 @@ void EDVMimeTypesListWinDelete(
 /*
  *	MIME Types List Window Progress callback.
  *
- *	For save, import, and export progress.
+ *	For open, save, import, and export progress.
  */
 static gint EDVMimeTypesListProgressCB(
 	gpointer data, const gulong pos, const gulong max
@@ -1992,9 +1994,9 @@ static void EDVMimeTypesListWinUpdateDisplay(
 			    if(cmd == NULL)
 				continue;
 
-                            name = cmd->name;
-                            if(name == NULL)
-                                continue;
+			    name = cmd->name;
+			    if(name == NULL)
+				continue;
 
 			    s_tmp = g_strconcat(
 				s2,
@@ -2296,8 +2298,11 @@ static void EDVMimeTypesListWinUpdateDisplay(
 
 
 /*
- *	Sets the MIME Types List Window's MIME Types clist row to the
- *	values specified by the given MIME Type.
+ *	Sets the MIME Types GtkCList row values.
+ *
+ *	The row specifies the row on the MIME Types GtkCList.
+ *
+ *	The m specifies the MIME Type.
  */
 void EDVMimeTypesListWinSetRow(
 	edv_mime_types_list_win_struct *lw,
@@ -2428,48 +2433,69 @@ void EDVMimeTypesListWinSetRow(
 }
 
 /*
- *	Regets the MIME Types List Window's list of MIME Types from the
- *	core structure.
+ *	Regets the MIME Types List.
  */
-void EDVMimeTypesListWinFetchValues(edv_mime_types_list_win_struct *lw)
+void EDVMimeTypesListWinFetchValues(
+	edv_mime_types_list_win_struct *lw,
+	const gboolean verbose
+)
 {
-	gint i, row;
+	gint i, nmimetypes, row, ncolumns, progress_update_mod;
 	gchar **strv;
+	GtkWidget *toplevel;
 	GtkCList *clist;
+	edv_mime_type_struct *m;
 	edv_core_struct *core;
-	edv_mime_type_struct *mt_ptr;
-
 
 	if(lw == NULL)
 	    return;
 
+	if(verbose && ProgressDialogIsQuery())
+	    return;
+
+	toplevel = lw->toplevel;
 	clist = (GtkCList *)lw->mimetypes_clist;
 	core = lw->core;
 	if((clist == NULL) || (core == NULL))
 	    return;
 
-	if(clist->columns < 1)
+	ncolumns = clist->columns;
+	if(ncolumns < 1)
 	    return;
 
-	/* Allocate row cell values */
-	strv = (gchar **)g_malloc(clist->columns * sizeof(gchar *));
-	for(i = 0; i < clist->columns; i++)
+	/* Allocate the row cell values */
+	strv = (gchar **)g_malloc(ncolumns * sizeof(gchar *));
+	for(i = 0; i < ncolumns; i++)
 	    strv[i] = "";
 
-
-	/* Begin updating MIME Types clist */
+	/* Map the progress dialog? */
+	if(verbose)
+	{
+	    ProgressDialogSetTransientFor(toplevel);
+	    ProgressDialogMap(
+		"Loading MIME Types",
+		"Loading MIME Types...",
+		(const guint8 **)icon_mimetypes_32x32_xpm,
+		"Stop"
+	    );
+	    gdk_flush();
+	}
 
 	gtk_clist_freeze(clist);
 
-	/* Remove existing rows on clist and clear display */
+	/* Remove the existing rows and clear the display */
 	gtk_clist_clear(clist);
 	EDVMimeTypesListWinUpdateDisplay(lw, -1, NULL);
 
-	/* Iterate through all MIME Types on the core structure */
-	for(i = 0; i < core->total_mimetypes; i++)
+	/* Iterate through all the MIME Types on the core and
+	 * add each one to the GtkCList
+	 */
+	nmimetypes = core->total_mimetypes;
+	progress_update_mod = MAX(nmimetypes / 100, 1);
+	for(i = 0; i < nmimetypes; i++)
 	{
-	    mt_ptr = core->mimetype[i];
-	    if(mt_ptr == NULL)
+	    m = core->mimetype[i];
+	    if(m == NULL)
 		continue;
 
 	    /* Append a new row and set the new row's values */
@@ -2477,15 +2503,31 @@ void EDVMimeTypesListWinFetchValues(edv_mime_types_list_win_struct *lw)
 	    if(row < 0)
 		break;
 
-	    EDVMimeTypesListWinSetRow(lw, row, mt_ptr);
+	    EDVMimeTypesListWinSetRow(lw, row, m);
+
+	    /* Report progress and check for user abort */
+	    if(verbose && ((i % progress_update_mod) == 0))
+	    {
+		if(EDVMimeTypesListProgressCB(
+		    lw, (gulong)(i + 1), (gulong)nmimetypes
+		))
+		    break;
+	    }
 	}
 
 	gtk_clist_thaw(clist);
 
-	/* Delete clist row cell values */
+	/* Delete the row cell values */
 	g_free(strv);
 
 	EDVMimeTypesListWinUpdateMenus(lw);
+
+	/* Unmap the progress dialog? */
+	if(verbose)
+	{
+	    ProgressDialogBreakQuery(TRUE);
+	    ProgressDialogSetTransientFor(NULL);
+	}
 }
 
 
@@ -2502,9 +2544,9 @@ void EDVMimeTypesListWinEdit(
 	    return;
 
 	d = lw->edit_dlg;
-        if(d == NULL)
-            lw->edit_dlg = d = EDVMimeTypeEditDlgNew(lw->core, lw);
-        if(d == NULL)
+	if(d == NULL)
+	    lw->edit_dlg = d = EDVMimeTypeEditDlgNew(lw->core, lw);
+	if(d == NULL)
 	    return;
 
 	EDVCenterWindowToWindow(lw->toplevel, d->toplevel);
