@@ -2052,12 +2052,12 @@ edv_recbin_struct *EDVRecBinNew(edv_core_struct *core)
 	GtkWidget *w, *parent, *parent2;
 	GtkCList *clist;
 	const GtkTargetEntry dnd_tar_types[] = {
-{"text/plain",				0,	EDV_DND_TYPE_INFO_TEXT_PLAIN},
-{"text/uri-list",			0,	EDV_DND_TYPE_INFO_TEXT_URI_LIST},
-{"STRING",				0,	EDV_DND_TYPE_INFO_STRING}
+{"text/plain",				0,	EDV_DND_INFO_TEXT_PLAIN},
+{"text/uri-list",			0,	EDV_DND_INFO_TEXT_URI_LIST},
+{"STRING",				0,	EDV_DND_INFO_STRING}
 	};
 	const GtkTargetEntry dnd_src_types[] = {
-{EDV_DND_TYPE_STRING_RECYCLED_OBJECT,	0,	EDV_DND_TYPE_INFO_RECYCLED_OBJECT}
+{EDV_DND_TARGET_RECYCLED_OBJECT,	0,	EDV_DND_INFO_RECYCLED_OBJECT}
 	};
 	const cfg_item_struct *cfg_list;
 	edv_status_bar_struct *status_bar;
