@@ -134,9 +134,9 @@ static gint EDVRecBinDNDConfirm(
 	}
 
 	/* Do confirmation, handle by dnd target type */
-	if((info == EDV_DND_TYPE_INFO_TEXT_PLAIN) ||
-	   (info == EDV_DND_TYPE_INFO_TEXT_URI_LIST) ||
-	   (info == EDV_DND_TYPE_INFO_STRING)
+	if((info == EDV_DND_INFO_TEXT_PLAIN) ||
+	   (info == EDV_DND_INFO_TEXT_URI_LIST) ||
+	   (info == EDV_DND_INFO_STRING)
 	)
 	{
 	    switch(gdk_action)
@@ -151,11 +151,11 @@ static gint EDVRecBinDNDConfirm(
 		break;
 	    }
 	}
-	else if(info == EDV_DND_TYPE_INFO_RECYCLED_OBJECT)
+	else if(info == EDV_DND_INFO_RECYCLED_OBJECT)
 	{
 	    /* Recycled objects mat not be put into the Recycle Bin */
 	}
-	else if(info == EDV_DND_TYPE_INFO_ARCHIVE_OBJECT)
+	else if(info == EDV_DND_INFO_ARCHIVE_OBJECT)
 	{
 	    /* Objects in archives may not be put into the Recycle Bin */
 	}
@@ -184,9 +184,9 @@ static void EDVRecBinDNDUpdateStatusBar(
 	    return;
 
 	/* Begin formatting status message, handle by dnd target type */
-	if((info == EDV_DND_TYPE_INFO_TEXT_PLAIN) ||
-	   (info == EDV_DND_TYPE_INFO_TEXT_URI_LIST) ||
-	   (info == EDV_DND_TYPE_INFO_STRING)
+	if((info == EDV_DND_INFO_TEXT_PLAIN) ||
+	   (info == EDV_DND_INFO_TEXT_URI_LIST) ||
+	   (info == EDV_DND_INFO_STRING)
 	)
 	{
 	    switch(gdk_action)
@@ -212,13 +212,13 @@ static void EDVRecBinDNDUpdateStatusBar(
 		break;
 	    }
 	}
-	else if(info == EDV_DND_TYPE_INFO_RECYCLED_OBJECT)
+	else if(info == EDV_DND_INFO_RECYCLED_OBJECT)
 	{
 	    /* Recycled objects may not be dragged back into the
 	     * Recycle Bin
 	     */
 	}
-	else if(info == EDV_DND_TYPE_INFO_ARCHIVE_OBJECT)
+	else if(info == EDV_DND_INFO_ARCHIVE_OBJECT)
 	{
 	    /* Archive objects may not be recycled */
 	}
@@ -278,9 +278,9 @@ static void EDVRecBinDragDataReceivedNexus(
 	);
 	/* User confirmed and dnd target type is a disk object? */
 	if((initial_confirmation_result == CDIALOG_RESPONSE_YES) &&
-	   ((info == EDV_DND_TYPE_INFO_TEXT_PLAIN) ||
-	    (info == EDV_DND_TYPE_INFO_TEXT_URI_LIST) ||
-	    (info == EDV_DND_TYPE_INFO_STRING)
+	   ((info == EDV_DND_INFO_TEXT_PLAIN) ||
+	    (info == EDV_DND_INFO_TEXT_URI_LIST) ||
+	    (info == EDV_DND_INFO_STRING)
 	   )
 	)
 	{
