@@ -12,6 +12,7 @@
 #include "../../include/prochandle.h"
 
 #include "../guiutils.h"
+#include "../fprompt.h"
 #include "../cdialog.h"
 #include "../progressdialog.h"
 #include "../fb.h"
@@ -216,17 +217,11 @@ static void TEditDelete(tedit_struct *te);
 "Save Changes?",					\
 "The text contains changes that have not been\n\
 saved, do you want to save those changes?", \
-"There are changes made to the text that have\n\
-not been saved. If you want to save those changes,\n\
-then click on \"Yes\". If you want to discard\n\
-those changes then click on \"No\". If you do not\n\
-want to continue with this operation then click\n\
-on \"Cancel\".",					\
+   NULL,						\
    CDIALOG_ICON_WARNING,				\
    CDIALOG_BTNFLAG_YES |				\
    CDIALOG_BTNFLAG_NO |					\
-   CDIALOG_BTNFLAG_CANCEL |				\
-   CDIALOG_BTNFLAG_HELP,				\
+   CDIALOG_BTNFLAG_CANCEL,				\
    CDIALOG_BTNFLAG_YES					\
   );							\
   CDialogSetTransientFor(NULL);				\
@@ -4400,6 +4395,7 @@ int main(int argc, char *argv[])
 	gdk_rgb_init();
 
 	/* Initialize the dialogs */
+	FPromptInit();
 	CDialogInit();
 	ProgressDialogInit();
 	FileBrowserInit();
@@ -4470,10 +4466,11 @@ int main(int argc, char *argv[])
 	ctx = NULL;
 
 	/* Shutdown dialogs */
-	CDialogShutdown();
-	ProgressDialogShutdown();
-	FileBrowserShutdown();
 	PDialogShutdown();
+	FileBrowserShutdown();
+	ProgressDialogShutdown();
+	CDialogShutdown();
+	FPromptShutdown();
 
 	/* Reset the DND Icon */
 	GUIDNDSetDragIcon(NULL, NULL, 0, 0);
