@@ -13,10 +13,10 @@
 
 
 void TViewScrollToLine(
-	tview_struct *tv, gint n,
-	gfloat ycoeff, gboolean move_cursor 
+	tview_struct *tv, const gint n,
+	const gfloat ycoeff, const gboolean move_cursor 
 );
-GtkVisibility TViewIsLineVisible(tview_struct *tv, gint n);
+GtkVisibility TViewIsLineVisible(tview_struct *tv, const gint n);
 
 gint TViewOpenFile(tview_struct *tv, const gchar *path);
 gint TViewSaveFile(tview_struct *tv, const gchar *path);
@@ -37,9 +37,9 @@ GtkMenu *TViewGetMenuWidget(tview_struct *tv);
 
 tview_struct *TViewNew(GtkWidget *parent);
 tview_struct *TViewNewWithToplevel(
-	gint width, gint height
+	const gint width, const gint height
 );
-void TViewSetReadOnly(tview_struct *tv, gboolean read_only);
+void TViewSetReadOnly(tview_struct *tv, const gboolean read_only);
 void TViewSetChangedCB(   
 	tview_struct *tv,
 	void (*changed_cb)(tview_struct *, gpointer),
@@ -47,7 +47,7 @@ void TViewSetChangedCB(
 );
 void TViewUpdate(tview_struct *tv);
 void TViewDraw(tview_struct *tv);
-void TViewSetBusy(tview_struct *tv, gboolean is_busy);
+void TViewSetBusy(tview_struct *tv, const gboolean busy);
 void TViewMap(tview_struct *tv);
 void TViewUnmap(tview_struct *tv);
 void TViewDelete(tview_struct *tv);
@@ -74,8 +74,8 @@ void TViewDelete(tview_struct *tv);
  *	Scrolls the Text View to the specified line.
  */
 void TViewScrollToLine(
-	tview_struct *tv, gint n,
-	gfloat ycoeff, gboolean move_cursor
+	tview_struct *tv, const gint n,
+	const gfloat ycoeff, const gboolean move_cursor
 )
 {
 	gfloat v;
@@ -132,7 +132,7 @@ void TViewScrollToLine(
 /*
  *	Checks if the specified line on the Text View is visible.
  */
-GtkVisibility TViewIsLineVisible(tview_struct *tv, gint n)
+GtkVisibility TViewIsLineVisible(tview_struct *tv, const gint n)
 {
 	gfloat v;
 	gint line_height;
@@ -184,9 +184,9 @@ gint TViewOpenFile(tview_struct *tv, const gchar *path)
 	/* Delete all text */                        
 	TViewClear(tv);
 
-	/* Reset has changes mark */
-	if(tv->has_changes)
-	    tv->has_changes = FALSE;
+	/* Reset the has changes marker */
+	if(TVIEW_HAS_CHANGES(tv))
+	    tv->flags &= ~TVIEW_FLAG_HAS_CHANGES;
 
 	if(STRISEMPTY(path))
 	    return(2);
@@ -351,9 +351,9 @@ gint TViewSaveFile(tview_struct *tv, const gchar *path)
 	fclose(fp);
 	g_free(buf);
 
-	/* Reset has changes mark */
-	if(tv->has_changes) 
-	    tv->has_changes = FALSE;
+	/* Reset the has changes marker */
+	if(TVIEW_HAS_CHANGES(tv))
+	    tv->flags &= ~TVIEW_FLAG_HAS_CHANGES;
 
 	TViewUpdate(tv);
 
@@ -372,12 +372,12 @@ gint TViewOpenData(tview_struct *tv, const gchar *data, gint data_len)
 	if(tv == NULL)
 	    return(-1);
 
-	/* Delete all text */
+	/* Delete all the text */
 	TViewClear(tv);
 
-	/* Reset has changes mark */
-	if(tv->has_changes)
-	    tv->has_changes = FALSE;
+	/* Reset the has changes marker */
+	if(TVIEW_HAS_CHANGES(tv))
+	    tv->flags &= ~TVIEW_FLAG_HAS_CHANGES;
 
 	w = tv->text;
 	if((w == NULL) || (data == NULL) || (data_len <= 0))
@@ -427,7 +427,7 @@ void TViewCut(tview_struct *tv)
 	if(w == NULL)
 	    return;
 
-	if(tv->read_only)
+	if(TVIEW_READ_ONLY(tv))
 	    return;
 
 	/* Copy selected text to clipboard */
@@ -443,7 +443,7 @@ void TViewCut(tview_struct *tv)
  */
 void TViewCopy(tview_struct *tv)
 {
-	guint8 *buf;
+	gchar *s;
 	gint i, len, sel_pos, sel_len;
 	GtkWidget *w = (tv != NULL) ? tv->text : NULL;
 	if(w == NULL)
@@ -479,16 +479,23 @@ void TViewCopy(tview_struct *tv)
 	    return;
 	}
 
-	/* Allocate buffer and copy selected data to it */
-	buf = (guint8 *)g_malloc(sel_len * sizeof(guint8));
+	/* Copy the selected string */
+	s = (gchar *)g_malloc((sel_len + 1) * sizeof(gchar));
+	if(s == NULL)
+	{
+	    gtk_text_thaw(GTK_TEXT(w));
+	    return;
+	}
+
 	for(i = 0; i < sel_len; i++)
-	    buf[i] = (guint8)GTK_TEXT_INDEX(GTK_TEXT(w), (guint)(sel_pos + i));
+	    s[i] = (gchar)GTK_TEXT_INDEX(GTK_TEXT(w), (guint)(sel_pos + i));
+	s[sel_len] = '\0';
 
-	/* Copy to clipboard */
-	GUIDDESetBinary(w, GDK_NONE, GDK_CURRENT_TIME, buf, sel_len);
+	/* Set the string to the clipboard */
+	GUIDDESetString(w, GDK_NONE, GDK_CURRENT_TIME, s);
 
-	/* Delete coppied buffer */
-	g_free(buf);
+	/* Delete the coppied string */
+	g_free(s);
 
 	gtk_text_thaw(GTK_TEXT(w));
 }
@@ -498,35 +505,36 @@ void TViewCopy(tview_struct *tv)
  */
 void TViewPaste(tview_struct *tv)
 {
-	guint8 *buf;
-	gint len;
+	gchar *s;
 	GtkWidget *w = (tv != NULL) ? tv->text : NULL;
 	if(w == NULL)
 	    return;
 
-	if(tv->read_only)
+	if(TVIEW_READ_ONLY(tv))
 	    return;
 
-	/* Get copy of data from clipboard */
-	buf = GUIDDEGetBinary(
+	/* Get the string from the clipboard */
+	s = GUIDDEGetString(
 	    w,
 	    GDK_NONE,
-	    GDK_CURRENT_TIME,
-	    &len
+	    GDK_CURRENT_TIME
 	);
+	if(s == NULL)
+	    return;
+
 #if 0
 	/* Paste data to text */
 	gtk_text_freeze(GTK_TEXT(w));
 	gtk_editable_select_region(
 	    GTK_EDITABLE(w), 
-	    0,     
-	    (gint)gtk_text_get_length(GTK_TEXT(w))     
+	    0,
+	    (gint)gtk_text_get_length(GTK_TEXT(w))
 	);
 	gtk_text_thaw(GTK_TEXT(w));
 #endif
 
-	/* Delete coppied data from clipboard */
-	g_free(buf);
+	/* Delete the string */
+	g_free(s);
 
 	TViewUpdate(tv);
 }
@@ -666,27 +674,20 @@ tview_struct *TViewNew(GtkWidget *parent)
 	if(tv == NULL)
 	    return(NULL);
 
-	/* Reset values */
 	tv->map_state = FALSE;
-	tv->read_only = FALSE;
-	tv->has_changes = FALSE;
-	tv->changed_cb = NULL;
-	tv->changed_data = NULL;
-
-	/* Load cursors */
+	tv->freeze_count = 0;
+	tv->busy_count = 0;
+	tv->flags = 0;
 	tv->busy_cur = gdk_cursor_new(GDK_WATCH);
 	tv->text_cur = gdk_cursor_new(GDK_XTERM);
 	tv->translate_cur = gdk_cursor_new(GDK_FLEUR);
-
-	/* Load fonts */
 	tv->text_font = gdk_font_load(
 "-adobe-courier-medium-r-normal-*-12-*-*-*-m-*-iso8859-1"
 	);
+	tv->changed_cb = NULL;
+	tv->changed_data = NULL;
 
-
-	/* Begin creating widgets */
-
-	/* Toplevel */
+	/* Toplevel GtkVBox */
 	tv->toplevel = w = gtk_vbox_new(FALSE, 0);
 	if(GTK_IS_BOX(parent))
 	    gtk_box_pack_start(GTK_BOX(parent), w, TRUE, TRUE, 0);
@@ -722,7 +723,7 @@ tview_struct *TViewNew(GtkWidget *parent)
 	    GTK_SIGNAL_FUNC(TViewTextEventCB), tv 
 	);
 	text->default_tab_width = 8;
-	gtk_text_set_editable(text, !tv->read_only);
+	gtk_text_set_editable(text, !TVIEW_READ_ONLY(tv));
 	gtk_text_set_word_wrap(text, TRUE);
 	gtk_table_attach(
 	    GTK_TABLE(parent2), w,
@@ -732,7 +733,7 @@ tview_struct *TViewNew(GtkWidget *parent)
 	    0, 0
 	);
 	gtk_signal_connect(
-	    GTK_OBJECT(w), "changed",   
+	    GTK_OBJECT(w), "changed",
 	    GTK_SIGNAL_FUNC(TViewChangedCB), tv
 	);
 	gtk_widget_show(w);
@@ -774,27 +775,27 @@ tview_struct *TViewNew(GtkWidget *parent)
 
 
 	/* Right-click menu */
-	if(TRUE)              
+	if(TRUE)
 	{
-#define DO_ADD_MENU_ITEM_LABEL  {               \
- w = GUIMenuItemCreate(                         \
-  menu, GUI_MENU_ITEM_TYPE_LABEL, accelgrp,     \
-  icon, label, accel_key, accel_mods, NULL,     \
-  mclient_data, func_cb                         \
+#define DO_ADD_MENU_ITEM_LABEL	{		\
+ w = GUIMenuItemCreate(				\
+  menu, GUI_MENU_ITEM_TYPE_LABEL, accelgrp,	\
+  icon, label, accel_key, accel_mods, NULL,	\
+  mclient_data, func_cb				\
  );						\
 }
-#define DO_ADD_MENU_ITEM_CHECK  {               \
- w = GUIMenuItemCreate(                         \
-  menu, GUI_MENU_ITEM_TYPE_CHECK, accelgrp,     \
-  icon, label, accel_key, accel_mods, NULL,     \
-  mclient_data, func_cb                         \
+#define DO_ADD_MENU_ITEM_CHECK	{		\
+ w = GUIMenuItemCreate(				\
+  menu, GUI_MENU_ITEM_TYPE_CHECK, accelgrp,	\
+  icon, label, accel_key, accel_mods, NULL,	\
+  mclient_data, func_cb				\
  );						\
 }
-#define DO_ADD_MENU_SEP         {               \
- w = GUIMenuItemCreate(                         \
-  menu, GUI_MENU_ITEM_TYPE_SEPARATOR, NULL,     \
-  NULL, NULL, 0, 0, NULL,                       \
-  NULL, NULL                                    \
+#define DO_ADD_MENU_SEP		{		\
+ w = GUIMenuItemCreate(				\
+  menu, GUI_MENU_ITEM_TYPE_SEPARATOR, NULL,	\
+  NULL, NULL, 0, 0, NULL,			\
+  NULL, NULL					\
  );						\
 }
 	    GtkWidget *menu = GUIMenuCreate();
@@ -942,7 +943,7 @@ tview_struct *TViewNew(GtkWidget *parent)
  *	Creates a new Text View with a toplevel GtkWindow.
  */
 tview_struct *TViewNewWithToplevel(
-	gint width, gint height
+	const gint width, const gint height
 )
 {
 	tview_struct *tv;
@@ -995,12 +996,12 @@ tview_struct *TViewNewWithToplevel(
 /*
  *	Sets the Text View as read only or read/write.
  */
-void TViewSetReadOnly(tview_struct *tv, gboolean read_only)
+void TViewSetReadOnly(tview_struct *tv, const gboolean read_only)
 {
 	if(tv == NULL)
 	    return;
 
-	if(tv->read_only != read_only)
+	if(TVIEW_READ_ONLY(tv) != read_only)
 	{
 	    GtkWidget *w = tv->text;
 	    if(w != NULL)
@@ -1008,7 +1009,10 @@ void TViewSetReadOnly(tview_struct *tv, gboolean read_only)
 		gtk_text_set_editable(GTK_TEXT(w), !read_only);
 	    }
 
-	    tv->read_only = read_only;
+	    if(read_only)
+		tv->flags |= TVIEW_FLAG_READ_ONLY;
+	    else
+		tv->flags &= ~TVIEW_FLAG_READ_ONLY;
 
 	    TViewDraw(tv);
 	    TViewUpdate(tv);
@@ -1044,12 +1048,12 @@ void TViewUpdate(tview_struct *tv)
 	    return;
 
 	w = tv->text;
-	read_only = tv->read_only;
+	read_only = TVIEW_READ_ONLY(tv);
 	sel_len = (w != NULL) ?
 	    ((gint)GTK_EDITABLE(w)->selection_end_pos -
 	     (gint)GTK_EDITABLE(w)->selection_start_pos) : 0;
 	has_selection = (sel_len != 0) ? TRUE : FALSE;
-	has_changes = tv->has_changes;
+	has_changes = TVIEW_HAS_CHANGES(tv);
 
 
 	/* Right click menu */
@@ -1085,7 +1089,7 @@ void TViewDraw(tview_struct *tv)
 /*
  *	Sets the Text View as busy or ready.
  */
-void TViewSetBusy(tview_struct *tv, gboolean is_busy)
+void TViewSetBusy(tview_struct *tv, const gboolean busy)
 {
 #define SET_CURSOR(_w_,_c_)		\
 { if((_w_) != NULL) {			\
@@ -1097,7 +1101,7 @@ void TViewSetBusy(tview_struct *tv, gboolean is_busy)
 	if(tv == NULL)
 	    return;
 
-	if(is_busy)
+	if(busy)
 	{
 	    /* Increase busy count */
 	    tv->busy_count++;
