@@ -12,6 +12,15 @@ typedef struct _tview_struct		tview_struct;
 #define TVIEW(p)			((tview_struct *)(p))
 
 
+/*
+ *	Flags:
+ */
+typedef enum {
+	TVIEW_FLAG_HAS_CHANGES		= (1 << 0),
+	TVIEW_FLAG_READ_ONLY		= (1 << 1)
+} tview_flags;
+
+
 /*
  *	Text View:
  */
@@ -19,10 +28,14 @@ struct _tview_struct {
 
 	GtkWidget	*toplevel;
 	gboolean	map_state;
-	gint		busy_count;
+	gint		freeze_count,
+			busy_count;
+	tview_flags	flags;
+
 	GdkCursor	*busy_cur,
 			*text_cur,
 			*translate_cur;
+
 	GdkFont		*text_font;
 
 	GtkWidget	*text,
@@ -41,9 +54,6 @@ struct _tview_struct {
 			*select_all_mi,
 			*unselect_all_mi;
 
-	gboolean	read_only;
-	gboolean	has_changes;
-
 	/* Changed callback */   
 	void		(*changed_cb)(
 		tview_struct *tv,		/* Text View */
@@ -53,12 +63,17 @@ struct _tview_struct {
 
 };
 
+#define TVIEW_HAS_CHANGES(_tv_)		\
+ ((_tv_)->flags & TVIEW_FLAG_HAS_CHANGES)
+#define TVIEW_READ_ONLY(_tv_)		\
+ ((_tv_)->flags & TVIEW_FLAG_READ_ONLY)
 
-extern void HViewScrollToLine(
-	tview_struct *tv, gint n,
-	gfloat ycoeff, gboolean move_cursor 
+
+extern void TViewScrollToLine(
+	tview_struct *tv, const gint n,
+	const gfloat ycoeff, const gboolean move_cursor 
 );
-extern GtkVisibility HViewIsLineVisible(tview_struct *tv, gint n);
+extern GtkVisibility TViewIsLineVisible(tview_struct *tv, const gint n);
 
 extern gint TViewOpenFile(tview_struct *tv, const gchar *path);
 extern gint TViewSaveFile(tview_struct *tv, const gchar *path);
@@ -79,9 +94,9 @@ extern GtkMenu *TViewGetMenuWidget(tview_struct *tv);
 
 extern tview_struct *TViewNew(GtkWidget *parent);
 extern tview_struct *TViewNewWithToplevel(
-	gint width, gint height
+	const gint width, const gint height
 );
-extern void TViewSetReadOnly(tview_struct *tv, gboolean read_only);
+extern void TViewSetReadOnly(tview_struct *tv, const gboolean read_only);
 extern void TViewSetChangedCB(
 	tview_struct *tv,
 	void (*changed_cb)(tview_struct *, gpointer),
@@ -89,7 +104,7 @@ extern void TViewSetChangedCB(
 );
 extern void TViewUpdate(tview_struct *tv);
 extern void TViewDraw(tview_struct *tv);
-extern void TViewSetBusy(tview_struct *tv, gboolean is_busy);
+extern void TViewSetBusy(tview_struct *tv, const gboolean busy);
 extern void TViewMap(tview_struct *tv);
 extern void TViewUnmap(tview_struct *tv);
 extern void TViewDelete(tview_struct *tv);
