@@ -218,9 +218,9 @@ void TViewChangedCB(GtkEditable *editable, gpointer data)
 	/* Text */
 	if(GTK_WIDGET(editable) == tv->text) 
 	{
-	    if(!tv->has_changes)
+	    if(!TVIEW_HAS_CHANGES(tv))
 	    {
-		tv->has_changes = TRUE;
+		tv->flags |= TVIEW_FLAG_HAS_CHANGES;
 		TViewUpdate(tv);
 	    }
 
